*Stata code for running the trade war  regressions


clear all
clear matrix
clear mata
* set maximum number of variables


set maxvar 40000
set matsize 11000

*** install as needed 
*ssc install ftools
**ssc install ppmlhdfe
*ssc install reghdfe

* set path



cd   "/Users/ko37/Dropbox/Trade War/Paper - Current Version/Replication Files Kevin/"

*load data

import delimited "bilateral_trade_q.csv"



tab country_1

tab country_2



* drop negative values in the export data

tab exports_1 if exports_1<0
replace exports_1=. if exports_1<0

tab exports_2 if exports_2<0
replace exports_2=. if exports_2<0





*********** convert exports to USD - use rate_gfd for all conversions - supplement with Obstfeld for Bulgaria  ************




g exportsGFD_1 = exports_1*rate_gfd_1/100
label var exportsGFD_1 "exports_1 in USD"

replace exportsGFD_1 = exports_1*rate_obstfeld_1/100 if code_1=="BGR"


g exportsGFD_2= exports_2*rate_gfd_2/100
label var exportsGFD_2 "exports_2 in USD

replace exportsGFD_2 = exports_2*rate_obstfeld_2/100 if code_2=="BGR"

*** substitute  the obstfeld exchange rates instead of gfd for Bulgaria so these get carried through
replace rate_gfd_1 = rate_obstfeld_1 if code_1=="BGR"

replace rate_gfd_2 = rate_obstfeld_2 if code_2=="BGR"


*** Drop unknown destinations or origins, and trade with oneself


drop if code_1 =="."

drop if code_2 =="."

drop if code_1 == code_2

*** (There are 72 observations where code_1==code_2 that get deleted)


*** The data is really missing if there is no data on either imports or exports

gen byte missing_exp = missing(exports_1)

gen byte missing_imp = missing(exports_2)

gen missing = missing_imp*missing_exp

drop if missing == 1   
*** (deleted 111 observations)



* drop countries/areas that can't be reasonably allocated.

drop if code_1=="AFR"
drop if code_1=="ATL"
drop if code_1=="AND"
drop if code_1=="ANT"
drop if code_1=="ARN"
drop if code_1=="AAD"
drop if code_1=="ARC"
drop if code_1=="AFP"
drop if code_1=="AAT"
drop if code_1=="BZO"
drop if code_1=="BAF"
drop if code_1=="BRC"
drop if code_1=="BEO"
drop if code_1=="BII"
drop if code_1=="ENA"
drop if code_1=="BPO"
drop if code_1=="BPP"
drop if code_1=="BSM"
drop if code_1=="BUN"
drop if code_1=="CHP"
drop if code_1=="DSF"
drop if code_1=="CNA"
drop if code_1=="DAM"
drop if code_1=="DUC"
drop if code_1=="EAF"
drop if code_1=="EEA"
drop if code_1=="ESL"
drop if code_1=="EUR"
drop if code_1=="FIU"
drop if code_1=="FAF"
drop if code_1=="FAM"
drop if code_1=="PFA"
drop if code_1=="FRC"
drop if code_1=="FME"
drop if code_1=="FSA"
drop if code_1=="FSH"
drop if code_1=="DAU"
drop if code_1=="GBI"
drop if code_1=="HPR"
drop if code_1=="HIS"
drop if code_1=="IFI"
drop if code_1=="INS"
drop if code_1=="IIS"
drop if code_1=="IPA"
drop if code_1=="ITI"
drop if code_1=="IAS"
drop if code_1=="KER"
drop if code_1=="KCW"
drop if code_1=="LAE"
drop if code_1=="LER"
drop if code_1=="MIS"
drop if code_1=="MNG"
drop if code_1=="NAF"
drop if code_1=="NAM"
drop if code_1=="OCE"
drop if code_1=="OTH"
drop if code_1=="OAF"
drop if code_1=="OAM"
drop if code_1=="OAS"
drop if code_1=="RAM"
drop if code_1=="OBR"
drop if code_1=="OBM"
drop if code_1=="OBA"
drop if code_1=="OBF"
drop if code_1=="OBP"
drop if code_1=="OMA"
drop if code_1=="OEA"
drop if code_1=="OEE"
drop if code_1=="OEU"
drop if code_1=="OFE"
drop if code_1=="OFA"
drop if code_1=="APF"
drop if code_1=="OFP"
drop if code_1=="ONA"
drop if code_1=="ONM"
drop if code_1=="OOC"
drop if code_1=="OEM"
drop if code_1=="OPL"
drop if code_1=="OSF"
drop if code_1=="OSA"
drop if code_1=="OSW"
drop if code_1=="AFA"
drop if code_1=="OHA"
drop if code_1=="OWA"
drop if code_1=="OWE"
drop if code_1=="OWS"
drop if code_1=="UBE"
drop if code_1=="PSY"
drop if code_1=="PLY"
drop if code_1=="POC"
drop if code_1=="PDB"
drop if code_1=="SAR"
drop if code_1=="WRE"
drop if code_1=="SMU"
drop if code_1=="SAM"
drop if code_1=="SSI"
drop if code_1=="AAF"
drop if code_1=="SAF"
drop if code_1=="SPC"
drop if code_1=="SGO"
drop if code_1=="SYM"
drop if code_1=="TGA"
drop if code_1=="TIB"
drop if code_1=="TUL"
drop if code_1=="UNK"
drop if code_1=="USO"
drop if code_1=="WHW"
drop if code_1=="WAF"
drop if code_1=="WAC"
drop if code_1=="WEA"
drop if code_1=="WIN"
drop if code_1=="WFB"
drop if code_1=="WFF"
drop if code_1=="WFN"
drop if code_1=="WFS"
drop if code_1=="BAS"
drop if code_1=="SWS"


drop if code_2=="AFR"
drop if code_2=="ATL"
drop if code_2=="AND"
drop if code_2=="ANT"
drop if code_2=="ARN"
drop if code_2=="AAD"
drop if code_2=="ARC"
drop if code_2=="AFP"
drop if code_2=="AAT"
drop if code_2=="BZO"
drop if code_2=="BAF"
drop if code_2=="BRC"
drop if code_2=="BEO"
drop if code_2=="BII"
drop if code_2=="ENA"
drop if code_2=="BPO"
drop if code_2=="BPP"
drop if code_2=="BSM"
drop if code_2=="BUN"
drop if code_2=="CHP"
drop if code_2=="DSF"
drop if code_2=="CNA"
drop if code_2=="DAM"
drop if code_2=="DUC"
drop if code_2=="EAF"
drop if code_2=="EEA"
drop if code_2=="ESL"
drop if code_2=="EUR"
drop if code_2=="FIU"
drop if code_2=="FAF"
drop if code_2=="FAM"
drop if code_2=="PFA"
drop if code_2=="FRC"
drop if code_2=="FME"
drop if code_2=="FSA"
drop if code_2=="FSH"
drop if code_2=="DAU"
drop if code_2=="GBI"
drop if code_2=="HPR"
drop if code_2=="HIS"
drop if code_2=="IFI"
drop if code_2=="INS"
drop if code_2=="IIS"
drop if code_2=="IPA"
drop if code_2=="ITI"
drop if code_2=="IAS"
drop if code_2=="KER"
drop if code_2=="KCW"
drop if code_2=="LAE"
drop if code_2=="LER"
drop if code_2=="MIS"
drop if code_2=="MNG"
drop if code_2=="NAF"
drop if code_2=="NAM"
drop if code_2=="OCE"
drop if code_2=="OTH"
drop if code_2=="OAF"
drop if code_2=="OAM"
drop if code_2=="OAS"
drop if code_2=="RAM"
drop if code_2=="OBR"
drop if code_2=="OBM"
drop if code_2=="OBA"
drop if code_2=="OBF"
drop if code_2=="OBP"
drop if code_2=="OMA"
drop if code_2=="OEA"
drop if code_2=="OEE"
drop if code_2=="OEU"
drop if code_2=="OFE"
drop if code_2=="OFA"
drop if code_2=="APF"
drop if code_2=="OFP"
drop if code_2=="ONA"
drop if code_2=="ONM"
drop if code_2=="OOC"
drop if code_2=="OEM"
drop if code_2=="OPL"
drop if code_2=="OSF"
drop if code_2=="OSA"
drop if code_2=="OSW"
drop if code_2=="AFA"
drop if code_2=="OHA"
drop if code_2=="OWA"
drop if code_2=="OWE"
drop if code_2=="OWS"
drop if code_2=="UBE"
drop if code_2=="PSY"
drop if code_2=="PLY"
drop if code_2=="POC"
drop if code_2=="PDB"
drop if code_2=="SAR"
drop if code_2=="WRE"
drop if code_2=="SMU"
drop if code_2=="SAM"
drop if code_2=="SSI"
drop if code_2=="AAF"
drop if code_2=="SAF"
drop if code_2=="SPC"
drop if code_2=="SGO"
drop if code_2=="SYM"
drop if code_2=="TGA"
drop if code_2=="TIB"
drop if code_2=="TUL"
drop if code_2=="UNK"
drop if code_2=="USO"
drop if code_2=="WHW"
drop if code_2=="WAF"
drop if code_2=="WAC"
drop if code_2=="WEA"
drop if code_2=="WIN"
drop if code_2=="WFB"
drop if code_2=="WFF"
drop if code_2=="WFN"
drop if code_2=="WFS"
drop if code_2=="BAS"
drop if code_2=="SWS"

*** The largest category here is OTH - Other wiht 828 observations, next largest OAS - Other Asia wiht 365, most others are in the single or double digits.

* combine merged areas  see file CountryAllocation.xls for details


*** Arabia ****

replace code_1="ARA" if code_1=="AON"
replace code_1="ARA" if code_1=="BRN"
replace code_1="ARA" if code_1=="BAR"
replace code_1="ARA" if code_1=="HAD"
replace code_1="ARA" if code_1=="HED"
replace code_1="ARA" if code_1=="HAM"
replace code_1="ARA" if code_1=="HEN"
replace code_1="ARA" if code_1=="KUW"
replace code_1="ARA" if code_1=="MTO"
replace code_1="ARA" if code_1=="MOK"
replace code_1="ARA" if code_1=="OMN"
replace code_1="ARA" if code_1=="SAU"
replace code_1="ARA" if code_1=="SDY"
replace code_1="ARA" if code_1=="SOO"
replace code_1="ARA" if code_1=="YEM"




replace country_1 ="ARABIA" if country_1=="ARABIA: OTHER NATIVE STATES"
replace country_1 ="ARABIA" if country_1=="BAHREIN"
replace country_1 ="ARABIA" if country_1=="BRITISH ARABIA"
replace country_1 ="ARABIA" if country_1=="HADRAMOUT"
replace country_1 ="ARABIA" if country_1=="HEDJAZ"
replace country_1 ="ARABIA" if country_1=="HEJAZ ARABIA AND MESOPOTAMIA"
replace country_1 ="ARABIA" if country_1=="HEJAZ-NEJD"
replace country_1 ="ARABIA" if country_1=="KUWAIT"
replace country_1 ="ARABIA" if country_1=="MUSCAT TERRITORY AND TRUCIAL OMAN"
replace country_1 ="ARABIA" if country_1=="MUSCAT, OMAN, TRUCIAL OMAN AND KUWAIT"
replace country_1 ="ARABIA" if country_1=="OMAN"
replace country_1 ="ARABIA" if country_1=="SAUDI ARABIA"
replace country_1 ="ARABIA" if country_1=="SAUDI ARABIA AND YEMEN"
replace country_1 ="ARABIA" if country_1=="SOCOTORA"
replace country_1 ="ARABIA" if country_1=="YEMEN"





replace code_2="ARA" if code_2=="AON"
replace code_2="ARA" if code_2=="BRN"
replace code_2="ARA" if code_2=="BAR"
replace code_2="ARA" if code_2=="HAD"
replace code_2="ARA" if code_2=="HED"
replace code_2="ARA" if code_2=="HAM"
replace code_2="ARA" if code_2=="HEN"
replace code_2="ARA" if code_2=="KUW"
replace code_2="ARA" if code_2=="MTO"
replace code_2="ARA" if code_2=="MOK"
replace code_2="ARA" if code_2=="OMN"
replace code_2="ARA" if code_2=="SAU"
replace code_2="ARA" if code_2=="SDY"
replace code_2="ARA" if code_2=="SOO"
replace code_2="ARA" if code_2=="YEM"




replace country_2 ="ARABIA" if country_2=="ARABIA: OTHER NATIVE STATES"
replace country_2 ="ARABIA" if country_2=="BAHREIN"
replace country_2 ="ARABIA" if country_2=="BRITISH ARABIA"
replace country_2 ="ARABIA" if country_2=="HADRAMOUT"
replace country_2 ="ARABIA" if country_2=="HEDJAZ"
replace country_2 ="ARABIA" if country_2=="HEJAZ ARABIA AND MESOPOTAMIA"
replace country_2 ="ARABIA" if country_2=="HEJAZ-NEJD"
replace country_2 ="ARABIA" if country_2=="KUWAIT"
replace country_2 ="ARABIA" if country_2=="MUSCAT TERRITORY AND TRUCIAL OMAN"
replace country_2 ="ARABIA" if country_2=="MUSCAT, OMAN, TRUCIAL OMAN AND KUWAIT"
replace country_2 ="ARABIA" if country_2=="OMAN"
replace country_2 ="ARABIA" if country_2=="SAUDI ARABIA"
replace country_2 ="ARABIA" if country_2=="SAUDI ARABIA AND YEMEN"
replace country_2 ="ARABIA" if country_2=="SOCOTORA"
replace country_2 ="ARABIA" if country_2=="YEMEN"


****  Ascension, Falklands and St Helena  ****
replace code_1="ASC" if code_1=="ASC"
replace code_1="ASC" if code_1=="ASH"
replace code_1="ASC" if code_1=="FAL"
replace code_1="ASC" if code_1=="STH"
replace code_1="ASC" if code_1=="TDC"



replace country_1 ="ASCENSION FALKLANDS STHELENA" if country_1=="ASCENSION"
replace country_1 ="ASCENSION FALKLANDS STHELENA" if country_1=="ASCENSION AND ST. HELENA"
replace country_1 ="ASCENSION FALKLANDS STHELENA" if country_1=="FALKLANDS"
replace country_1 ="ASCENSION FALKLANDS STHELENA" if country_1=="ST HELENA"
replace country_1 ="ASCENSION FALKLANDS STHELENA" if country_1=="TRISTAN DA CUNHA"



replace code_2="ASC" if code_2=="ASC"
replace code_2="ASC" if code_2=="ASH"
replace code_2="ASC" if code_2=="FAL"
replace code_2="ASC" if code_2=="STH"
replace code_2="ASC" if code_2=="TDC"



replace country_2 ="ASCENSION FALKLANDS STHELENA" if country_2=="ASCENSION"
replace country_2 ="ASCENSION FALKLANDS STHELENA" if country_2=="ASCENSION AND ST. HELENA"
replace country_2 ="ASCENSION FALKLANDS STHELENA" if country_2=="FALKLANDS"
replace country_2 ="ASCENSION FALKLANDS STHELENA" if country_2=="ST HELENA"
replace country_2 ="ASCENSION FALKLANDS STHELENA" if country_2=="TRISTAN DA CUNHA"


**** Belgian Africa ***

replace code_1="BPA" if code_1=="BLC"
replace code_1="BPA" if code_1=="BCO"
replace code_1="BPA" if code_1=="COG"
replace code_1="BPA" if code_1=="RUR"
replace code_1="BPA" if code_1=="RWA"



replace country_1 ="BELGIAN AFRICA" if country_1=="BELGIAN COLONIES"
replace country_1 ="BELGIAN AFRICA" if country_1=="BELGIAN CONGO"
replace country_1 ="BELGIAN AFRICA" if country_1=="CONGO"
replace country_1 ="BELGIAN AFRICA" if country_1=="RUANDA AND URUNDI"
replace country_1 ="BELGIAN AFRICA" if country_1=="RWANDA"



replace code_2="BPA" if code_2=="BLC"
replace code_2="BPA" if code_2=="BCO"
replace code_2="BPA" if code_2=="COG"
replace code_2="BPA" if code_2=="RUR"
replace code_2="BPA" if code_2=="RWA"



replace country_2 ="BELGIAN AFRICA" if country_2=="BELGIAN COLONIES"
replace country_2 ="BELGIAN AFRICA" if country_2=="BELGIAN CONGO"
replace country_2 ="BELGIAN AFRICA" if country_2=="CONGO"
replace country_2 ="BELGIAN AFRICA" if country_2=="RUANDA AND URUNDI"
replace country_2 ="BELGIAN AFRICA" if country_2=="RWANDA"


**** Belgium and Luxemburg ****


replace code_1="BLX" if code_1=="BEL"
replace code_1="BLX" if code_1=="LUX"


replace country_1 ="BELGIUM AND LUXEMBURG" if country_1=="BELGIUM"
replace country_1 ="BELGIUM AND LUXEMBURG" if country_1=="LUXEMBURG"


replace code_2="BLX" if code_2=="BEL"
replace code_2="BLX" if code_2=="LUX"


replace country_2 ="BELGIUM AND LUXEMBURG" if country_2=="BELGIUM"
replace country_2 ="BELGIUM AND LUXEMBURG" if country_2=="LUXEMBURG"

**** Bhutan and Nepal ****



replace code_1="BNL" if code_1=="BTN"
replace code_1="BNL" if code_1=="NPL"

replace country_1 ="BHUTAN AND NEPAL" if country_1=="BHUTAN"
replace country_1 ="BHUTAN AND NEPAL" if country_1=="NEPAL"


replace code_2="BNL" if code_2=="BTN"
replace code_2="BNL" if code_2=="NPL"

replace country_2 ="BHUTAN AND NEPAL" if country_2=="BHUTAN"
replace country_2 ="BHUTAN AND NEPAL" if country_2=="NEPAL"

**** BRITISH EAST AFRICA ****



replace code_1="BEA" if code_1=="EWA"
replace code_1="BEA" if code_1=="BOE"
replace code_1="BEA" if code_1=="SOM"
replace code_1="BEA" if code_1=="KEN"
replace code_1="BEA" if code_1=="KEU"
replace code_1="BEA" if code_1=="KUT"
replace code_1="BEA" if code_1=="TAN"
replace code_1="BEA" if code_1=="UGA"
replace code_1="BEA" if code_1=="ZAN"
replace code_1="BEA" if code_1=="ZAP"


replace country_1 ="BRITISH EAST AFRICA" if country_1=="BRITISH EAST AND WEST EQUATORIAL AFRICA"
replace country_1 ="BRITISH EAST AFRICA" if country_1=="BRITISH EAST EQUATORIAL AFRICA"
replace country_1 ="BRITISH EAST AFRICA" if country_1=="BRITISH SOMALILAND"
replace country_1 ="BRITISH EAST AFRICA" if country_1=="KENYA"
replace country_1 ="BRITISH EAST AFRICA" if country_1=="KENYA AND UGANDA"
replace country_1 ="BRITISH EAST AFRICA" if country_1=="KENYA, UGANDA & TANGANYIKA"
replace country_1 ="BRITISH EAST AFRICA" if country_1=="TANGANYIKA"
replace country_1 ="BRITISH EAST AFRICA" if country_1=="UGANDA"
replace country_1 ="BRITISH EAST AFRICA" if country_1=="ZANZIBAR"
replace country_1 ="BRITISH EAST AFRICA" if country_1=="ZANZIBAR AND PEMBA"




replace code_2="BEA" if code_2=="EWA"
replace code_2="BEA" if code_2=="BOE"
replace code_2="BEA" if code_2=="SOM"
replace code_2="BEA" if code_2=="KEN"
replace code_2="BEA" if code_2=="KEU"
replace code_2="BEA" if code_2=="KUT"
replace code_2="BEA" if code_2=="TAN"
replace code_2="BEA" if code_2=="UGA"
replace code_2="BEA" if code_2=="ZAN"
replace code_2="BEA" if code_2=="ZAP"


replace country_2 ="BRITISH EAST AFRICA" if country_2=="BRITISH EAST AND WEST EQUATORIAL AFRICA"
replace country_2 ="BRITISH EAST AFRICA" if country_2=="BRITISH EAST EQUATORIAL AFRICA"
replace country_2 ="BRITISH EAST AFRICA" if country_2=="BRITISH SOMALILAND"
replace country_2 ="BRITISH EAST AFRICA" if country_2=="KENYA"
replace country_2 ="BRITISH EAST AFRICA" if country_2=="KENYA AND UGANDA"
replace country_2 ="BRITISH EAST AFRICA" if country_2=="KENYA, UGANDA & TANGANYIKA"
replace country_2 ="BRITISH EAST AFRICA" if country_2=="TANGANYIKA"
replace country_2 ="BRITISH EAST AFRICA" if country_2=="UGANDA"
replace country_2 ="BRITISH EAST AFRICA" if country_2=="ZANZIBAR"
replace country_2 ="BRITISH EAST AFRICA" if country_2=="ZANZIBAR AND PEMBA"



**** British East Indies ****

replace code_1="BEI" if code_1=="BBO"
replace code_1="BEI" if code_1=="BMC"
replace code_1="BEI" if code_1=="BMA"
replace code_1="BEI" if code_1=="BNB"
replace code_1="BEI" if code_1=="BRU"
replace code_1="BEI" if code_1=="FMS"
replace code_1="BEI" if code_1=="MCC"
replace code_1="BEI" if code_1=="MAL"
replace code_1="BEI" if code_1=="MYS"
replace code_1="BEI" if code_1=="NBO"
replace code_1="BEI" if code_1=="OBE"
replace code_1="BEI" if code_1=="SWK"
replace code_1="BEI" if code_1=="SGP"
replace code_1="BEI" if code_1=="STR"
replace code_1="BEI" if code_1=="STS"
replace code_1="BEI" if code_1=="SSD"
replace code_1="BEI" if code_1=="JKP"



replace country_1 ="BRITISH EAST INDIES" if country_1=="BRITISH BORNEO"
replace country_1 ="BRITISH EAST INDIES" if country_1=="BRITISH MALACCA"
replace country_1 ="BRITISH EAST INDIES" if country_1=="BRITISH MALAYA"
replace country_1 ="BRITISH EAST INDIES" if country_1=="BRITISH NORTH BORNEO"
replace country_1 ="BRITISH EAST INDIES" if country_1=="BRUNEI"
replace country_1 ="BRITISH EAST INDIES" if country_1=="FEDERATED MALAY STATES"
replace country_1 ="BRITISH EAST INDIES" if country_1=="MALAKKA"
replace country_1 ="BRITISH EAST INDIES" if country_1=="MALAY STATES"
replace country_1 ="BRITISH EAST INDIES" if country_1=="MALAYSIA"
replace country_1 ="BRITISH EAST INDIES" if country_1=="NORTH BORNEO"
replace country_1 ="BRITISH EAST INDIES" if country_1=="OTHER BRITISH EAST INDIES"
replace country_1 ="BRITISH EAST INDIES" if country_1=="SARAWAK"
replace country_1 ="BRITISH EAST INDIES" if country_1=="SINGAPORE"
replace country_1 ="BRITISH EAST INDIES" if country_1=="STRAITS AND F.M.S."
replace country_1 ="BRITISH EAST INDIES" if country_1=="STRAITS SETTLEMENTS"
replace country_1 ="BRITISH EAST INDIES" if country_1=="STRAITS SETTLEMENTS AND LABUAN"
replace country_1 ="BRITISH EAST INDIES" if country_1=="UNFEDERATED MALAY STATES"



replace code_2="BEI" if code_2=="BBO"
replace code_2="BEI" if code_2=="BMC"
replace code_2="BEI" if code_2=="BMA"
replace code_2="BEI" if code_2=="BNB"
replace code_2="BEI" if code_2=="BRU"
replace code_2="BEI" if code_2=="FMS"
replace code_2="BEI" if code_2=="MCC"
replace code_2="BEI" if code_2=="MAL"
replace code_2="BEI" if code_2=="MYS"
replace code_2="BEI" if code_2=="NBO"
replace code_2="BEI" if code_2=="OBE"
replace code_2="BEI" if code_2=="SWK"
replace code_2="BEI" if code_2=="SGP"
replace code_2="BEI" if code_2=="STR"
replace code_2="BEI" if code_2=="STS"
replace code_2="BEI" if code_2=="SSD"
replace code_2="BEI" if code_2=="JKP"



replace country_2 ="BRITISH EAST INDIES" if country_2=="BRITISH BORNEO"
replace country_2 ="BRITISH EAST INDIES" if country_2=="BRITISH MALACCA"
replace country_2 ="BRITISH EAST INDIES" if country_2=="BRITISH MALAYA"
replace country_2 ="BRITISH EAST INDIES" if country_2=="BRITISH NORTH BORNEO"
replace country_2 ="BRITISH EAST INDIES" if country_2=="BRUNEI"
replace country_2 ="BRITISH EAST INDIES" if country_2=="FEDERATED MALAY STATES"
replace country_2 ="BRITISH EAST INDIES" if country_2=="MALAKKA"
replace country_2 ="BRITISH EAST INDIES" if country_2=="MALAY STATES"
replace country_2 ="BRITISH EAST INDIES" if country_2=="MALAYSIA"
replace country_2 ="BRITISH EAST INDIES" if country_2=="NORTH BORNEO"
replace country_2 ="BRITISH EAST INDIES" if country_2=="OTHER BRITISH EAST INDIES"
replace country_2 ="BRITISH EAST INDIES" if country_2=="SARAWAK"
replace country_2 ="BRITISH EAST INDIES" if country_2=="SINGAPORE"
replace country_2 ="BRITISH EAST INDIES" if country_2=="STRAITS AND F.M.S."
replace country_2 ="BRITISH EAST INDIES" if country_2=="STRAITS SETTLEMENTS"
replace country_2 ="BRITISH EAST INDIES" if country_2=="STRAITS SETTLEMENTS AND LABUAN"
replace country_2 ="BRITISH EAST INDIES" if country_2=="UNFEDERATED MALAY STATES"


**** BRITISH MEDITERRANEAN ****


replace code_1="BME" if code_1=="CYP"
replace code_1="BME" if code_1=="GIB"
replace code_1="BME" if code_1=="MGI"
replace code_1="BME" if code_1=="MLT"
replace code_1="BME" if code_1=="MGO"
replace code_1="BME" if code_1=="MGC"


replace country_1 ="BRITISH MEDITERRANEAN" if country_1=="CYPRUS"
replace country_1 ="BRITISH MEDITERRANEAN" if country_1=="GIBRALTAR"
replace country_1 ="BRITISH MEDITERRANEAN" if country_1=="GIBRALTAR ET MALTA"
replace country_1 ="BRITISH MEDITERRANEAN" if country_1=="MALTA"
replace country_1 ="BRITISH MEDITERRANEAN" if country_1=="MALTA AND GOZO"
replace country_1 ="BRITISH MEDITERRANEAN" if country_1=="MALTA GOZO AND CYPRUS"



replace code_2="BME" if code_2=="CYP"
replace code_2="BME" if code_2=="GIB"
replace code_2="BME" if code_2=="MGI"
replace code_2="BME" if code_2=="MLT"
replace code_2="BME" if code_2=="MGO"
replace code_2="BME" if code_2=="MGC"


replace country_2 ="BRITISH MEDITERRANEAN" if country_2=="CYPRUS"
replace country_2 ="BRITISH MEDITERRANEAN" if country_2=="GIBRALTAR"
replace country_2 ="BRITISH MEDITERRANEAN" if country_2=="GIBRALTAR ET MALTA"
replace country_2 ="BRITISH MEDITERRANEAN" if country_2=="MALTA"
replace country_2 ="BRITISH MEDITERRANEAN" if country_2=="MALTA AND GOZO"
replace country_2 ="BRITISH MEDITERRANEAN" if country_2=="MALTA GOZO AND CYPRUS"


 **** BRITISH OCEANIA ****

 
replace code_1="BOC" if code_1=="ATA"
replace code_1="BOC" if code_1=="AUS"
replace code_1="BOC" if code_1=="AUN"
replace code_1="BOC" if code_1=="AUO"
replace code_1="BOC" if code_1=="BOC"
replace code_1="BOC" if code_1=="BSI"
replace code_1="BOC" if code_1=="COO"
replace code_1="BOC" if code_1=="FIJ"
replace code_1="BOC" if code_1=="GEI"
replace code_1="BOC" if code_1=="NRU"
replace code_1="BOC" if code_1=="NBS"
replace code_1="BOC" if code_1=="NWS"
replace code_1="BOC" if code_1=="NGU"
replace code_1="BOC" if code_1=="HEB"
replace code_1="BOC" if code_1=="NZL"
replace code_1="BOC" if code_1=="NZO"
replace code_1="BOC" if code_1=="OAU"
replace code_1="BOC" if code_1=="OBO"
replace code_1="BOC" if code_1=="OPB"
replace code_1="BOC" if code_1=="PAP"
replace code_1="BOC" if code_1=="PNG"
replace code_1="BOC" if code_1=="ROS"
replace code_1="BOC" if code_1=="WSM"
replace code_1="BOC" if code_1=="TON"
 
 
replace country_1 ="BRITISH OCEANIA" if country_1=="AUSTRALASIA"
replace country_1 ="BRITISH OCEANIA" if country_1=="AUSTRALIA"
replace country_1 ="BRITISH OCEANIA" if country_1=="AUSTRALIA AND NEW ZEALAND"
replace country_1 ="BRITISH OCEANIA" if country_1=="AUSTRALIA OCEANIA"
replace country_1 ="BRITISH OCEANIA" if country_1=="BRITISH SOLOMON ISLANDS"
replace country_1 ="BRITISH OCEANIA" if country_1=="COOK ISLANDS"
replace country_1 ="BRITISH OCEANIA" if country_1=="FIJI"
replace country_1 ="BRITISH OCEANIA" if country_1=="GILBERTE AND ELLICE ISLANDS"
replace country_1 ="BRITISH OCEANIA" if country_1=="NAURU"
replace country_1 ="BRITISH OCEANIA" if country_1=="NAURU AND BRITISH SAMOA"
replace country_1 ="BRITISH OCEANIA" if country_1=="NAURU AND WESTERN SAMOA"
replace country_1 ="BRITISH OCEANIA" if country_1=="NEW GUINEA"
replace country_1 ="BRITISH OCEANIA" if country_1=="NEW HEBRIDES"
replace country_1 ="BRITISH OCEANIA" if country_1=="NEW ZEALAND"
replace country_1 ="BRITISH OCEANIA" if country_1=="NEW ZEALAND AND OCEANIA"
replace country_1 ="BRITISH OCEANIA" if country_1=="OTHER AUSTRALIA"
replace country_1 ="BRITISH OCEANIA" if country_1=="OTHER BRITISH OCEANIA"
replace country_1 ="BRITISH OCEANIA" if country_1=="OTHER ISLANDS IN THE PACIFIC (BRITISH)"
replace country_1 ="BRITISH OCEANIA" if country_1=="PAPUA"
replace country_1 ="BRITISH OCEANIA" if country_1=="PAPUA NEW GUINEA"
replace country_1 ="BRITISH OCEANIA" if country_1=="ROSS DEPENDENCY"
replace country_1 ="BRITISH OCEANIA" if country_1=="SAMOA"
replace country_1 ="BRITISH OCEANIA" if country_1=="TONGA"





replace code_2="BOC" if code_2=="ATA"
replace code_2="BOC" if code_2=="AUS"
replace code_2="BOC" if code_2=="AUN"
replace code_2="BOC" if code_2=="AUO"
replace code_2="BOC" if code_2=="BOC"
replace code_2="BOC" if code_2=="BSI"
replace code_2="BOC" if code_2=="COO"
replace code_2="BOC" if code_2=="FIJ"
replace code_2="BOC" if code_2=="GEI"
replace code_2="BOC" if code_2=="NRU"
replace code_2="BOC" if code_2=="NBS"
replace code_2="BOC" if code_2=="NWS"
replace code_2="BOC" if code_2=="NGU"
replace code_2="BOC" if code_2=="HEB"
replace code_2="BOC" if code_2=="NZL"
replace code_2="BOC" if code_2=="NZO"
replace code_2="BOC" if code_2=="OAU"
replace code_2="BOC" if code_2=="OBO"
replace code_2="BOC" if code_2=="OPB"
replace code_2="BOC" if code_2=="PAP"
replace code_2="BOC" if code_2=="PNG"
replace code_2="BOC" if code_2=="ROS"
replace code_2="BOC" if code_2=="WSM"
replace code_2="BOC" if code_2=="TON"
 
 
replace country_2 ="BRITISH OCEANIA" if country_2=="AUSTRALASIA"
replace country_2 ="BRITISH OCEANIA" if country_2=="AUSTRALIA"
replace country_2 ="BRITISH OCEANIA" if country_2=="AUSTRALIA AND NEW ZEALAND"
replace country_2 ="BRITISH OCEANIA" if country_2=="AUSTRALIA OCEANIA"
replace country_2 ="BRITISH OCEANIA" if country_2=="BRITISH SOLOMON ISLANDS"
replace country_2 ="BRITISH OCEANIA" if country_2=="COOK ISLANDS"
replace country_2 ="BRITISH OCEANIA" if country_2=="FIJI"
replace country_2 ="BRITISH OCEANIA" if country_2=="GILBERTE AND ELLICE ISLANDS"
replace country_2 ="BRITISH OCEANIA" if country_2=="NAURU"
replace country_2 ="BRITISH OCEANIA" if country_2=="NAURU AND BRITISH SAMOA"
replace country_2 ="BRITISH OCEANIA" if country_2=="NAURU AND WESTERN SAMOA"
replace country_2 ="BRITISH OCEANIA" if country_2=="NEW GUINEA"
replace country_2 ="BRITISH OCEANIA" if country_2=="NEW HEBRIDES"
replace country_2 ="BRITISH OCEANIA" if country_2=="NEW ZEALAND"
replace country_2 ="BRITISH OCEANIA" if country_2=="NEW ZEALAND AND OCEANIA"
replace country_2 ="BRITISH OCEANIA" if country_2=="OTHER AUSTRALIA"
replace country_2 ="BRITISH OCEANIA" if country_2=="OTHER BRITISH OCEANIA"
replace country_2 ="BRITISH OCEANIA" if country_2=="OTHER ISLANDS IN THE PACIFIC (BRITISH)"
replace country_2 ="BRITISH OCEANIA" if country_2=="PAPUA"
replace country_2 ="BRITISH OCEANIA" if country_2=="PAPUA NEW GUINEA"
replace country_2 ="BRITISH OCEANIA" if country_2=="ROSS DEPENDENCY"
replace country_2 ="BRITISH OCEANIA" if country_2=="SAMOA"
replace country_2 ="BRITISH OCEANIA" if country_2=="TONGA"


**** British Southern Africa - OBS ****

replace code_1="OBS" if code_1=="NER"
replace code_1="OBS" if code_1=="NWR"
replace code_1="OBS" if code_1=="NRH"
replace code_1="OBS" if code_1=="NRC"
replace code_1="OBS" if code_1=="NYA"
replace code_1="OBS" if code_1=="RDA"
replace code_1="OBS" if code_1=="SRH"



replace country_1 ="BRITISH SOUTHERN AFRICA" if country_1=="NORTH EASTERN RHODESIA"
replace country_1 ="BRITISH SOUTHERN AFRICA" if country_1=="NORTH WEST RHODESIA"
replace country_1 ="BRITISH SOUTHERN AFRICA" if country_1=="NORTHERN RHODESIA"
replace country_1 ="BRITISH SOUTHERN AFRICA" if country_1=="NORTHERN RHODESIA/CONGO BASIN"
replace country_1 ="BRITISH SOUTHERN AFRICA" if country_1=="NYASALAND"
replace country_1 ="BRITISH SOUTHERN AFRICA" if country_1=="OTHER BRITISH SOUTH AFRICA"
replace country_1 ="BRITISH SOUTHERN AFRICA" if country_1=="RHODESIA"
replace country_1 ="BRITISH SOUTHERN AFRICA" if country_1=="SOUTHERN RHODESIA"



replace code_2="OBS" if code_2=="NER"
replace code_2="OBS" if code_2=="NWR"
replace code_2="OBS" if code_2=="NRH"
replace code_2="OBS" if code_2=="NRC"
replace code_2="OBS" if code_2=="NYA"
replace code_2="OBS" if code_2=="RDA"
replace code_2="OBS" if code_2=="SRH"



replace country_2 ="BRITISH SOUTHERN AFRICA" if country_2=="NORTH EASTERN RHODESIA"
replace country_2 ="BRITISH SOUTHERN AFRICA" if country_2=="NORTH WEST RHODESIA"
replace country_2 ="BRITISH SOUTHERN AFRICA" if country_2=="NORTHERN RHODESIA"
replace country_2 ="BRITISH SOUTHERN AFRICA" if country_2=="NORTHERN RHODESIA/CONGO BASIN"
replace country_2 ="BRITISH SOUTHERN AFRICA" if country_2=="NYASALAND"
replace country_2 ="BRITISH SOUTHERN AFRICA" if country_2=="OTHER BRITISH SOUTH AFRICA"
replace country_2 ="BRITISH SOUTHERN AFRICA" if country_2=="RHODESIA"
replace country_2 ="BRITISH SOUTHERN AFRICA" if country_2=="SOUTHERN RHODESIA"



**** British Sudan - BSU ****
replace code_1="BSU" if code_1=="AES"
replace code_1="BSU" if code_1=="SDN"


replace country_1 ="BRITISH SUDAN" if country_1=="ANGLO-EGYPTIAN SUDAN"
replace country_1 ="BRITISH SUDAN" if country_1=="SUDAN"



replace code_2="BSU" if code_2=="AES"
replace code_2="BSU" if code_2=="SDN"


replace country_2 ="BRITISH SUDAN" if country_2=="ANGLO-EGYPTIAN SUDAN"
replace country_2 ="BRITISH SUDAN" if country_2=="SUDAN"


**** British West Africa - BWA ****

replace code_1="BWA" if code_1=="CBR"
replace code_1="BWA" if code_1=="BTO"
replace code_1="BWA" if code_1=="BWE"
replace code_1="BWA" if code_1=="GAM"
replace code_1="BWA" if code_1=="GCO"
replace code_1="BWA" if code_1=="GOT"
replace code_1="BWA" if code_1=="NGA"
replace code_1="BWA" if code_1=="NBC"
replace code_1="BWA" if code_1=="OBW"
replace code_1="BWA" if code_1=="SLE"


replace country_1 ="BRITISH WEST AFRICA" if country_1=="BRITISH CAMEROON"
replace country_1 ="BRITISH WEST AFRICA" if country_1=="BRITISH TOGO"
replace country_1 ="BRITISH WEST AFRICA" if country_1=="BRITISH WEST EQUATORIAL AFRICA"
replace country_1 ="BRITISH WEST AFRICA" if country_1=="GAMBIA"
replace country_1 ="BRITISH WEST AFRICA" if country_1=="GOLD COAST"
replace country_1 ="BRITISH WEST AFRICA" if country_1=="GOLD COAST AND BRITISH TOGOLAND"
replace country_1 ="BRITISH WEST AFRICA" if country_1=="NIGERIA"
replace country_1 ="BRITISH WEST AFRICA" if country_1=="NIGERIA AND BRITISH CAMEROON"
replace country_1 ="BRITISH WEST AFRICA" if country_1=="OTHER BRITISH WEST AFRICA"
replace country_1 ="BRITISH WEST AFRICA" if country_1=="SIERRA LEONE"



replace code_2="BWA" if code_2=="CBR"
replace code_2="BWA" if code_2=="BTO"
replace code_2="BWA" if code_2=="BWE"
replace code_2="BWA" if code_2=="GAM"
replace code_2="BWA" if code_2=="GCO"
replace code_2="BWA" if code_2=="GOT"
replace code_2="BWA" if code_2=="NGA"
replace code_2="BWA" if code_2=="NBC"
replace code_2="BWA" if code_2=="OBW"
replace code_2="BWA" if code_2=="SLE"


replace country_2 ="BRITISH WEST AFRICA" if country_2=="BRITISH CAMEROON"
replace country_2 ="BRITISH WEST AFRICA" if country_2=="BRITISH TOGO"
replace country_2 ="BRITISH WEST AFRICA" if country_2=="BRITISH WEST EQUATORIAL AFRICA"
replace country_2 ="BRITISH WEST AFRICA" if country_2=="GAMBIA"
replace country_2 ="BRITISH WEST AFRICA" if country_2=="GOLD COAST"
replace country_2 ="BRITISH WEST AFRICA" if country_2=="GOLD COAST AND BRITISH TOGOLAND"
replace country_2 ="BRITISH WEST AFRICA" if country_2=="NIGERIA"
replace country_2 ="BRITISH WEST AFRICA" if country_2=="NIGERIA AND BRITISH CAMEROON"
replace country_2 ="BRITISH WEST AFRICA" if country_2=="OTHER BRITISH WEST AFRICA"
replace country_2 ="BRITISH WEST AFRICA" if country_2=="SIERRA LEONE"



**** British West Indies _ BWI ****


replace code_1="BWI" if code_1=="AGA"
replace code_1="BWI" if code_1=="ABG"
replace code_1="BWI" if code_1=="BHS"
replace code_1="BWI" if code_1=="BRB"
replace code_1="BWI" if code_1=="BMU"
replace code_1="BWI" if code_1=="ANB"
replace code_1="BWI" if code_1=="BGU"
replace code_1="BWI" if code_1=="BHO"
replace code_1="BWI" if code_1=="CAY"
replace code_1="BWI" if code_1=="GRD"
replace code_1="BWI" if code_1=="GUY"
replace code_1="BWI" if code_1=="JAM"
replace code_1="BWI" if code_1=="JAN"
replace code_1="BWI" if code_1=="LEE"
replace code_1="BWI" if code_1=="OBC"
replace code_1="BWI" if code_1=="OWI"
replace code_1="BWI" if code_1=="STC"
replace code_1="BWI" if code_1=="STL"
replace code_1="BWI" if code_1=="STV"
replace code_1="BWI" if code_1=="TRI"
replace code_1="BWI" if code_1=="TAT"
replace code_1="BWI" if code_1=="IDU"
replace code_1="BWI" if code_1=="WWI"


replace country_1 ="BRITISH WEST INDIES" if country_1=="ANTIGUA"
replace country_1 ="BRITISH WEST INDIES" if country_1=="ANTILLES AND BRITISH GUIANA"
replace country_1 ="BRITISH WEST INDIES" if country_1=="BAHAMAS"
replace country_1 ="BRITISH WEST INDIES" if country_1=="BARBADOS"
replace country_1 ="BRITISH WEST INDIES" if country_1=="BERMUDA"
replace country_1 ="BRITISH WEST INDIES" if country_1=="BRITISH ANTILLES"
replace country_1 ="BRITISH WEST INDIES" if country_1=="BRITISH GUIANA"
replace country_1 ="BRITISH WEST INDIES" if country_1=="BRITISH HONDURAS"
replace country_1 ="BRITISH WEST INDIES" if country_1=="CAYMAN ISLANDS"
replace country_1 ="BRITISH WEST INDIES" if country_1=="GRENADA"
replace country_1 ="BRITISH WEST INDIES" if country_1=="GUIANA"
replace country_1 ="BRITISH WEST INDIES" if country_1=="JAMAICA"
replace country_1 ="BRITISH WEST INDIES" if country_1=="JAMAICA AND ANTILLES"
replace country_1 ="BRITISH WEST INDIES" if country_1=="LEEWARD ISLANDS"
replace country_1 ="BRITISH WEST INDIES" if country_1=="OTHER BRITISH CARIBBEAN"
replace country_1 ="BRITISH WEST INDIES" if country_1=="OTHER BRITISH WEST INDIES"
replace country_1 ="BRITISH WEST INDIES" if country_1=="ST CHRISTOPHER"
replace country_1 ="BRITISH WEST INDIES" if country_1=="ST LUCIA"
replace country_1 ="BRITISH WEST INDIES" if country_1=="ST VINCENT"
replace country_1 ="BRITISH WEST INDIES" if country_1=="TRINIDAD"
replace country_1 ="BRITISH WEST INDIES" if country_1=="TRINIDAD AND TOBAGO"
replace country_1 ="BRITISH WEST INDIES" if country_1=="UNION ISLAND"
replace country_1 ="BRITISH WEST INDIES" if country_1=="WINWARD ISLANDS"





replace code_2="BWI" if code_2=="AGA"
replace code_2="BWI" if code_2=="ABG"
replace code_2="BWI" if code_2=="BHS"
replace code_2="BWI" if code_2=="BRB"
replace code_2="BWI" if code_2=="BMU"
replace code_2="BWI" if code_2=="ANB"
replace code_2="BWI" if code_2=="BGU"
replace code_2="BWI" if code_2=="BHO"
replace code_2="BWI" if code_2=="CAY"
replace code_2="BWI" if code_2=="GRD"
replace code_2="BWI" if code_2=="GUY"
replace code_2="BWI" if code_2=="JAM"
replace code_2="BWI" if code_2=="JAN"
replace code_2="BWI" if code_2=="LEE"
replace code_2="BWI" if code_2=="OBC"
replace code_2="BWI" if code_2=="OWI"
replace code_2="BWI" if code_2=="STC"
replace code_2="BWI" if code_2=="STL"
replace code_2="BWI" if code_2=="STV"
replace code_2="BWI" if code_2=="TRI"
replace code_2="BWI" if code_2=="TAT"
replace code_2="BWI" if code_2=="IDU"
replace code_2="BWI" if code_2=="WWI"


replace country_2 ="BRITISH WEST INDIES" if country_2=="ANTIGUA"
replace country_2 ="BRITISH WEST INDIES" if country_2=="ANTILLES AND BRITISH GUIANA"
replace country_2 ="BRITISH WEST INDIES" if country_2=="BAHAMAS"
replace country_2 ="BRITISH WEST INDIES" if country_2=="BARBADOS"
replace country_2 ="BRITISH WEST INDIES" if country_2=="BERMUDA"
replace country_2 ="BRITISH WEST INDIES" if country_2=="BRITISH ANTILLES"
replace country_2 ="BRITISH WEST INDIES" if country_2=="BRITISH GUIANA"
replace country_2 ="BRITISH WEST INDIES" if country_2=="BRITISH HONDURAS"
replace country_2 ="BRITISH WEST INDIES" if country_2=="CAYMAN ISLANDS"
replace country_2 ="BRITISH WEST INDIES" if country_2=="GRENADA"
replace country_2 ="BRITISH WEST INDIES" if country_2=="GUIANA"
replace country_2 ="BRITISH WEST INDIES" if country_2=="JAMAICA"
replace country_2 ="BRITISH WEST INDIES" if country_2=="JAMAICA AND ANTILLES"
replace country_2 ="BRITISH WEST INDIES" if country_2=="LEEWARD ISLANDS"
replace country_2 ="BRITISH WEST INDIES" if country_2=="OTHER BRITISH CARIBBEAN"
replace country_2 ="BRITISH WEST INDIES" if country_2=="OTHER BRITISH WEST INDIES"
replace country_2 ="BRITISH WEST INDIES" if country_2=="ST CHRISTOPHER"
replace country_2 ="BRITISH WEST INDIES" if country_2=="ST LUCIA"
replace country_2 ="BRITISH WEST INDIES" if country_2=="ST VINCENT"
replace country_2 ="BRITISH WEST INDIES" if country_2=="TRINIDAD"
replace country_2 ="BRITISH WEST INDIES" if country_2=="TRINIDAD AND TOBAGO"
replace country_2 ="BRITISH WEST INDIES" if country_2=="UNION ISLAND"
replace country_2 ="BRITISH WEST INDIES" if country_2=="WINWARD ISLANDS"



**** China - CHN ****

replace code_1="CHN" if code_1=="CEM"
replace code_1="CHN" if code_1=="OCH"


replace country_1 ="CHINA" if country_1=="CHINA AND MANCHURIA"
replace country_1 ="CHINA" if country_1=="OTHER CHINA"





replace code_2="CHN" if code_2=="CEM"
replace code_2="CHN" if code_2=="OCH"


replace country_2 ="CHINA" if country_2=="CHINA AND MANCHURIA"
replace country_2 ="CHINA" if country_2=="OTHER CHINA"



**** COLOMBIA - COL ****


replace code_1="COL" if code_1=="CGA"	

replace country_1 ="COLOMBIA" if country_1=="COLOMBIA AND GALAPAGOS"




replace code_2="COL" if code_2=="CGA"	

replace country_2 ="COLOMBIA" if country_2=="COLOMBIA AND GALAPAGOS"

**** Dominican Republic - DOM ****


replace code_1="DOM" if code_1=="SAD"

replace country_1 ="DOMINICAN REPUBLIC" if country_1=="SAN DOMINGO"



replace code_2="DOM" if code_2=="SAD"

replace country_2 ="DOMINICAN REPUBLIC" if country_2=="SAN DOMINGO"
**** Dutch East Indies - DEI ****

replace code_1="DEI" if code_1=="BOJ"
replace code_1="DEI" if code_1=="DUB"
replace code_1="DEI" if code_1=="DUI"
replace code_1="DEI" if code_1=="DNG"
replace code_1="DEI" if code_1=="JMD"
replace code_1="DEI" if code_1=="ODE"
replace code_1="DEI" if code_1=="ODP"


replace country_1 ="DUTCH EAST INDIES" if country_1=="BORNEO AND JAVA"
replace country_1 ="DUTCH EAST INDIES" if country_1=="DUTCH BORNEO"
replace country_1 ="DUTCH EAST INDIES" if country_1=="DUTCH INDIA"
replace country_1 ="DUTCH EAST INDIES" if country_1=="DUTCH NEW GUINEA"
replace country_1 ="DUTCH EAST INDIES" if country_1=="JAVA AND MADURA"
replace country_1 ="DUTCH EAST INDIES" if country_1=="OTHER DUTCH EAST INDIES"
replace country_1 ="DUTCH EAST INDIES" if country_1=="OTHER DUTCH POSSESSIONS IN THE INDIAN SEAS"




replace code_2="DEI" if code_2=="BOJ"
replace code_2="DEI" if code_2=="DUB"
replace code_2="DEI" if code_2=="DUI"
replace code_2="DEI" if code_2=="DNG"
replace code_2="DEI" if code_2=="JMD"
replace code_2="DEI" if code_2=="ODE"
replace code_2="DEI" if code_2=="ODP"


replace country_2 ="DUTCH EAST INDIES" if country_2=="BORNEO AND JAVA"
replace country_2 ="DUTCH EAST INDIES" if country_2=="DUTCH BORNEO"
replace country_2 ="DUTCH EAST INDIES" if country_2=="DUTCH INDIA"
replace country_2 ="DUTCH EAST INDIES" if country_2=="DUTCH NEW GUINEA"
replace country_2 ="DUTCH EAST INDIES" if country_2=="JAVA AND MADURA"
replace country_2 ="DUTCH EAST INDIES" if country_2=="OTHER DUTCH EAST INDIES"
replace country_2 ="DUTCH EAST INDIES" if country_2=="OTHER DUTCH POSSESSIONS IN THE INDIAN SEAS"



**** Dutch West Indies ****


replace code_1="DWI" if code_1=="CUR"
replace code_1="DWI" if code_1=="NAN"
replace code_1="DWI" if code_1=="DUG"


replace country_1 ="DUTCH WEST INDIES" if country_1=="CURACAO"
replace country_1 ="DUTCH WEST INDIES" if country_1=="DUTCH ANTILLES"
replace country_1 ="DUTCH WEST INDIES" if country_1=="DUTCH GUIANA"





replace code_2="DWI" if code_2=="CUR"
replace code_2="DWI" if code_2=="NAN"
replace code_2="DWI" if code_2=="DUG"


replace country_2 ="DUTCH WEST INDIES" if country_2=="CURACAO"
replace country_2 ="DUTCH WEST INDIES" if country_2=="DUTCH ANTILLES"
replace country_2 ="DUTCH WEST INDIES" if country_2=="DUTCH GUIANA"



**** France - FRA ****


replace code_1="FRA" if code_1=="ELO"

replace country_1 ="FRANCE" if country_1=="ALSACE LORRAINE"



replace code_2="FRA" if code_2=="ELO"

replace country_2 ="FRANCE" if country_2=="ALSACE LORRAINE"
**** French East Africa - FOA ****


replace code_1="FOA" if code_1=="FSC"

replace country_1 ="FRENCH EAST AFRICA" if country_1=="FRENCH SOMALI COAST"



replace code_2="FOA" if code_2=="FSC"

replace country_2 ="FRENCH EAST AFRICA" if country_2=="FRENCH SOMALI COAST"


****  French East Indies FEI ****

replace code_1="FEI" if code_1=="COC"
replace code_1="FEI" if code_1=="FPI"
replace code_1="FEI" if code_1=="FIC"
replace code_1="FEI" if code_1=="ICH"

replace country_1 ="FRENCH EAST INDIES" if country_1=="COCHIN CHINA"
replace country_1 ="FRENCH EAST INDIES" if country_1=="FRENCH INDIA"
replace country_1 ="FRENCH EAST INDIES" if country_1=="FRENCH INDOCHINA"
replace country_1 ="FRENCH EAST INDIES" if country_1=="INDO-CHINA"



replace code_2="FEI" if code_2=="COC"
replace code_2="FEI" if code_2=="FPI"
replace code_2="FEI" if code_2=="FIC"
replace code_2="FEI" if code_2=="ICH"

replace country_2 ="FRENCH EAST INDIES" if country_2=="COCHIN CHINA"
replace country_2 ="FRENCH EAST INDIES" if country_2=="FRENCH INDIA"
replace country_2 ="FRENCH EAST INDIES" if country_2=="FRENCH INDOCHINA"
replace country_2 ="FRENCH EAST INDIES" if country_2=="INDO-CHINA"





**** French North Africa - FNA ****


replace code_1="FNA" if code_1=="DZA"
replace code_1="FNA" if code_1=="ALT"
replace code_1="FNA" if code_1=="FMO"
replace code_1="FNA" if code_1=="MTA"
replace code_1="FNA" if code_1=="MOR"
replace code_1="FNA" if code_1=="TNS"
replace code_1="FNA" if code_1=="TUN"


replace country_1 ="FRENCH NORTH AFRICA" if country_1=="ALGERIA"
replace country_1 ="FRENCH NORTH AFRICA" if country_1=="ALGERIA AND TUNIS"
replace country_1 ="FRENCH NORTH AFRICA" if country_1=="FRENCH MOROCCO"
replace country_1 ="FRENCH NORTH AFRICA" if country_1=="FRENCH MOROCCO AND TANGER"
replace country_1 ="FRENCH NORTH AFRICA" if country_1=="MOROCCO"
replace country_1 ="FRENCH NORTH AFRICA" if country_1=="TUNIS"
replace country_1 ="FRENCH NORTH AFRICA" if country_1=="TUNISIA"



replace code_2="FNA" if code_2=="DZA"
replace code_2="FNA" if code_2=="ALT"
replace code_2="FNA" if code_2=="FMO"
replace code_2="FNA" if code_2=="MTA"
replace code_2="FNA" if code_2=="MOR"
replace code_2="FNA" if code_2=="TNS"
replace code_2="FNA" if code_2=="TUN"


replace country_2 ="FRENCH NORTH AFRICA" if country_2=="ALGERIA"
replace country_2 ="FRENCH NORTH AFRICA" if country_2=="ALGERIA AND TUNIS"
replace country_2 ="FRENCH NORTH AFRICA" if country_2=="FRENCH MOROCCO"
replace country_2 ="FRENCH NORTH AFRICA" if country_2=="FRENCH MOROCCO AND TANGER"
replace country_2 ="FRENCH NORTH AFRICA" if country_2=="MOROCCO"
replace country_2 ="FRENCH NORTH AFRICA" if country_2=="TUNIS"
replace country_2 ="FRENCH NORTH AFRICA" if country_2=="TUNISIA"


 **** French Oceania FOC ****
 
 
replace code_1="FOC" if code_1=="NCL"
replace code_1="FOC" if code_1=="SOC"


replace country_1 ="FRENCH OCEANIA" if country_1=="NEW CALEDONIA"
replace country_1 ="FRENCH OCEANIA" if country_1=="SOCIETY ISLANDS"



 
replace code_2="FOC" if code_2=="NCL"
replace code_2="FOC" if code_2=="SOC"


replace country_2 ="FRENCH OCEANIA" if country_2=="NEW CALEDONIA"
replace country_2 ="FRENCH OCEANIA" if country_2=="SOCIETY ISLANDS"





**** French West Africa FWA ****

replace code_1="FWA" if code_1=="CDI"
replace code_1="FWA" if code_1=="DAH"
replace code_1="FWA" if code_1=="DAK"
replace code_1="FWA" if code_1=="CFR"
replace code_1="FWA" if code_1=="FCO"
replace code_1="FWA" if code_1=="FEA"
replace code_1="FWA" if code_1=="GNF"
replace code_1="FWA" if code_1=="NIG"
replace code_1="FWA" if code_1=="FSD"
replace code_1="FWA" if code_1=="FTO"
replace code_1="FWA" if code_1=="FWE"
replace code_1="FWA" if code_1=="FEQ"
replace code_1="FWA" if code_1=="MAU"
replace code_1="FWA" if code_1=="OFW"
replace code_1="FWA" if code_1=="SEN"
replace code_1="FWA" if code_1=="TOG"
replace code_1="FWA" if code_1=="FUV"


replace country_1 ="FRENCH WEST AFRICA" if country_1=="COTE D'IVOIRE"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="DAHOMEY"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="DAKAR"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="FRENCH CAMEROON"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="FRENCH CONGO"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="FRENCH EQUATORIAL AFRICA"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="FRENCH GUINEA"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="FRENCH NIGER"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="FRENCH SUDAN"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="FRENCH TOGO"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="FRENCH WEST AND EQUATORIAL AFRICA"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="FRENCH WEST EQUATORIAL AFRICA"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="MAURITANIA"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="OTHER FRENCH WEST AFRICA"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="SENEGAL"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="TOGO"
replace country_1 ="FRENCH WEST AFRICA" if country_1=="UPPER VOLTA"



replace code_2="FWA" if code_2=="CDI"
replace code_2="FWA" if code_2=="DAH"
replace code_2="FWA" if code_2=="DAK"
replace code_2="FWA" if code_2=="CFR"
replace code_2="FWA" if code_2=="FCO"
replace code_2="FWA" if code_2=="FEA"
replace code_2="FWA" if code_2=="GNF"
replace code_2="FWA" if code_2=="NIG"
replace code_2="FWA" if code_2=="FSD"
replace code_2="FWA" if code_2=="FTO"
replace code_2="FWA" if code_2=="FWE"
replace code_2="FWA" if code_2=="FEQ"
replace code_2="FWA" if code_2=="MAU"
replace code_2="FWA" if code_2=="OFW"
replace code_2="FWA" if code_2=="SEN"
replace code_2="FWA" if code_2=="TOG"
replace code_2="FWA" if code_2=="FUV"


replace country_2 ="FRENCH WEST AFRICA" if country_2=="COTE D'IVOIRE"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="DAHOMEY"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="DAKAR"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="FRENCH CAMEROON"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="FRENCH CONGO"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="FRENCH EQUATORIAL AFRICA"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="FRENCH GUINEA"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="FRENCH NIGER"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="FRENCH SUDAN"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="FRENCH TOGO"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="FRENCH WEST AND EQUATORIAL AFRICA"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="FRENCH WEST EQUATORIAL AFRICA"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="MAURITANIA"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="OTHER FRENCH WEST AFRICA"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="SENEGAL"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="TOGO"
replace country_2 ="FRENCH WEST AFRICA" if country_2=="UPPER VOLTA"





**** French West Indies FWI ****

replace code_1="FWI" if code_1=="ANF"
replace code_1="FWI" if code_1=="GUF"
replace code_1="FWI" if code_1=="GLP"
replace code_1="FWI" if code_1=="MAR"


replace country_1 ="FRENCH WEST INDIES" if country_1=="FRENCH ANTILLES"
replace country_1 ="FRENCH WEST INDIES" if country_1=="FRENCH GUIANA"
replace country_1 ="FRENCH WEST INDIES" if country_1=="GUADELOUPE"
replace country_1 ="FRENCH WEST INDIES" if country_1=="MARTINIQUE"





replace code_2="FWI" if code_2=="ANF"
replace code_2="FWI" if code_2=="GUF"
replace code_2="FWI" if code_2=="GLP"
replace code_2="FWI" if code_2=="MAR"


replace country_2 ="FRENCH WEST INDIES" if country_2=="FRENCH ANTILLES"
replace country_2 ="FRENCH WEST INDIES" if country_2=="FRENCH GUIANA"
replace country_2 ="FRENCH WEST INDIES" if country_2=="GUADELOUPE"
replace country_2 ="FRENCH WEST INDIES" if country_2=="MARTINIQUE"




****  Germany DEU ****

replace code_1="DEU" if code_1=="NFP"

replace country_1 ="GERMANY" if country_1=="NORTH SEA FREE PORTS"



replace code_2="DEU" if code_2=="NFP"

replace country_2 ="GERMANY" if country_2=="NORTH SEA FREE PORTS"

**** INDIA - IND ****

replace code_1="IND" if code_1=="ADE"
replace code_1="IND" if code_1=="BIB"
replace code_1="IND" if code_1=="BIC"
replace code_1="IND" if code_1=="BUR"
replace code_1="IND" if code_1=="CEY"
replace code_1="IND" if code_1=="OBN"

replace country_1 ="INDIA" if country_1=="ADEN"
replace country_1 ="INDIA" if country_1=="BRITISH INDIA AND BURMA"
replace country_1 ="INDIA" if country_1=="BRITISH INDIA AND CEYLON"
replace country_1 ="INDIA" if country_1=="BURMA"
replace country_1 ="INDIA" if country_1=="CEYLON"
replace country_1 ="INDIA" if country_1=="OTHER BRITISH INDIA"




replace code_2="IND" if code_2=="ADE"
replace code_2="IND" if code_2=="BIB"
replace code_2="IND" if code_2=="BIC"
replace code_2="IND" if code_2=="BUR"
replace code_2="IND" if code_2=="CEY"
replace code_2="IND" if code_2=="OBN"

replace country_2 ="INDIA" if country_2=="ADEN"
replace country_2 ="INDIA" if country_2=="BRITISH INDIA AND BURMA"
replace country_2 ="INDIA" if country_2=="BRITISH INDIA AND CEYLON"
replace country_2 ="INDIA" if country_2=="BURMA"
replace country_2 ="INDIA" if country_2=="CEYLON"
replace country_2 ="INDIA" if country_2=="OTHER BRITISH INDIA"


**** IRAN IRAQ AFGHANISTAN - AFG ****

replace code_1="AFG" if code_1=="IRN"
replace code_1="AFG" if code_1=="AFI"
replace code_1="AFG" if code_1=="IRQ"
replace code_1="AFG" if code_1=="IAG"
replace code_1="AFG" if code_1=="MES"
replace code_1="AFG" if code_1=="PMA"


replace country_1 ="IRAN IRAQ AND AFGHANISTAN" if country_1=="AFGHANISTAN"
replace country_1 ="IRAN IRAQ AND AFGHANISTAN" if country_1=="IRAN"
replace country_1 ="IRAN IRAQ AND AFGHANISTAN" if country_1=="IRAN AND AFGHANISTAN"
replace country_1 ="IRAN IRAQ AND AFGHANISTAN" if country_1=="IRAQ"
replace country_1 ="IRAN IRAQ AND AFGHANISTAN" if country_1=="IRAQ AND AFGHANISTAN"
replace country_1 ="IRAN IRAQ AND AFGHANISTAN" if country_1=="MESOPOTAMIA"
replace country_1 ="IRAN IRAQ AND AFGHANISTAN" if country_1=="PERSIA MESOPOTAMIA AFGHANISTAN"



replace code_2="AFG" if code_2=="IRN"
replace code_2="AFG" if code_2=="AFI"
replace code_2="AFG" if code_2=="IRQ"
replace code_2="AFG" if code_2=="IAG"
replace code_2="AFG" if code_2=="MES"
replace code_2="AFG" if code_2=="PMA"


replace country_2 ="IRAN IRAQ AND AFGHANISTAN" if country_2=="AFGHANISTAN"
replace country_2 ="IRAN IRAQ AND AFGHANISTAN" if country_2=="IRAN"
replace country_2 ="IRAN IRAQ AND AFGHANISTAN" if country_2=="IRAN AND AFGHANISTAN"
replace country_2 ="IRAN IRAQ AND AFGHANISTAN" if country_2=="IRAQ"
replace country_2 ="IRAN IRAQ AND AFGHANISTAN" if country_2=="IRAQ AND AFGHANISTAN"
replace country_2 ="IRAN IRAQ AND AFGHANISTAN" if country_2=="MESOPOTAMIA"
replace country_2 ="IRAN IRAQ AND AFGHANISTAN" if country_2=="PERSIA MESOPOTAMIA AFGHANISTAN"





****  Italian Africa IAF ****

replace code_1="IAF" if code_1=="CYR"
replace code_1="IAF" if code_1=="ERI"
replace code_1="IAF" if code_1=="EIS"
replace code_1="IAF" if code_1=="IEA"
replace code_1="IAF" if code_1=="ISO"
replace code_1="IAF" if code_1=="LBY"
replace code_1="IAF" if code_1=="OIA"
replace code_1="IAF" if code_1=="TRP"
replace code_1="IAF" if code_1=="TRC"


replace country_1 ="ITALIAN AFRICA" if country_1=="CYRENAICA"
replace country_1 ="ITALIAN AFRICA" if country_1=="ERITREA"
replace country_1 ="ITALIAN AFRICA" if country_1=="ERITREA AND ITALIAN SOMALI COAST"
replace country_1 ="ITALIAN AFRICA" if country_1=="ITALIAN EAST AFRICA"
replace country_1 ="ITALIAN AFRICA" if country_1=="ITALIAN SOMALILAND"
replace country_1 ="ITALIAN AFRICA" if country_1=="LIBYA"
replace country_1 ="ITALIAN AFRICA" if country_1=="OTHER ITALIAN AFRICA"
replace country_1 ="ITALIAN AFRICA" if country_1=="TRIPOLI"
replace country_1 ="ITALIAN AFRICA" if country_1=="TRIPOLITANIA AND CIRENAICA"





replace code_2="IAF" if code_2=="CYR"
replace code_2="IAF" if code_2=="ERI"
replace code_2="IAF" if code_2=="EIS"
replace code_2="IAF" if code_2=="IEA"
replace code_2="IAF" if code_2=="ISO"
replace code_2="IAF" if code_2=="LBY"
replace code_2="IAF" if code_2=="OIA"
replace code_2="IAF" if code_2=="TRP"
replace code_2="IAF" if code_2=="TRC"


replace country_2 ="ITALIAN AFRICA" if country_2=="CYRENAICA"
replace country_2 ="ITALIAN AFRICA" if country_2=="ERITREA"
replace country_2 ="ITALIAN AFRICA" if country_2=="ERITREA AND ITALIAN SOMALI COAST"
replace country_2 ="ITALIAN AFRICA" if country_2=="ITALIAN EAST AFRICA"
replace country_2 ="ITALIAN AFRICA" if country_2=="ITALIAN SOMALILAND"
replace country_2 ="ITALIAN AFRICA" if country_2=="LIBYA"
replace country_2 ="ITALIAN AFRICA" if country_2=="OTHER ITALIAN AFRICA"
replace country_2 ="ITALIAN AFRICA" if country_2=="TRIPOLI"
replace country_2 ="ITALIAN AFRICA" if country_2=="TRIPOLITANIA AND CIRENAICA"



**** Italy ITA ****


replace code_1="ITA" if code_1=="DOD"
replace code_1="ITA" if code_1=="IAI"
replace code_1="ITA" if code_1=="TST"

replace country_1 ="ITALY" if country_1=="DODECANESE"
replace country_1 ="ITALY" if country_1=="ITALIAN AEGEAN ISLANDS"
replace country_1 ="ITALY" if country_1=="TRIEST"





replace code_2="ITA" if code_2=="DOD"
replace code_2="ITA" if code_2=="IAI"
replace code_2="ITA" if code_2=="TST"

replace country_2 ="ITALY" if country_2=="DODECANESE"
replace country_2 ="ITALY" if country_2=="ITALIAN AEGEAN ISLANDS"
replace country_2 ="ITALY" if country_2=="TRIEST"


**** Japan - JPN ****

replace code_1="JPN" if code_1=="CHO"
replace code_1="JPN" if code_1=="FOR"
replace code_1="JPN" if code_1=="JFC"
replace code_1="JPN" if code_1=="JPF"
replace code_1="JPN" if code_1=="JPK"
replace code_1="JPN" if code_1=="JAI"
replace code_1="JPN" if code_1=="JIO"
replace code_1="JPN" if code_1=="KOR"
replace code_1="JPN" if code_1=="MSS"

replace country_1 ="JAPAN" if country_1=="CHOSEN"
replace country_1 ="JAPAN" if country_1=="FORMOSA"
replace country_1 ="JAPAN" if country_1=="JAPAN (INCLUDING FORMOSA AND JAPANESE LEASED TERRITORIES IN CHINA)"
replace country_1 ="JAPAN" if country_1=="JAPAN AND FORMOSA"
replace country_1 ="JAPAN" if country_1=="JAPAN AND KOREA"
replace country_1 ="JAPAN" if country_1=="JAPANESE ISLANDS"
replace country_1 ="JAPAN" if country_1=="JAPANESE OCEANIA"
replace country_1 ="JAPAN" if country_1=="KOREA"
replace country_1 ="JAPAN" if country_1=="SOUTH SEA MANDATE"



replace code_2="JPN" if code_2=="CHO"
replace code_2="JPN" if code_2=="FOR"
replace code_2="JPN" if code_2=="JFC"
replace code_2="JPN" if code_2=="JPF"
replace code_2="JPN" if code_2=="JPK"
replace code_2="JPN" if code_2=="JAI"
replace code_2="JPN" if code_2=="JIO"
replace code_2="JPN" if code_2=="KOR"
replace code_2="JPN" if code_2=="MSS"

replace country_2 ="JAPAN" if country_2=="CHOSEN"
replace country_2 ="JAPAN" if country_2=="FORMOSA"
replace country_2 ="JAPAN" if country_2=="JAPAN (INCLUDING FORMOSA AND JAPANESE LEASED TERRITORIES IN CHINA)"
replace country_2 ="JAPAN" if country_2=="JAPAN AND FORMOSA"
replace country_2 ="JAPAN" if country_2=="JAPAN AND KOREA"
replace country_2 ="JAPAN" if country_2=="JAPANESE ISLANDS"
replace country_2 ="JAPAN" if country_2=="JAPANESE OCEANIA"
replace country_2 ="JAPAN" if country_2=="KOREA"
replace country_2 ="JAPAN" if country_2=="SOUTH SEA MANDATE"




****  Madagascar and Reunion MDR ****

replace code_1="MDR" if code_1=="MDG"
replace code_1="MDR" if code_1=="REU"

replace country_1 ="MADAGASCAR AND REUNION" if country_1=="MADAGASCAR"
replace country_1 ="MADAGASCAR AND REUNION" if country_1=="REUNION"



replace code_2="MDR" if code_2=="MDG"
replace code_2="MDR" if code_2=="REU"

replace country_2 ="MADAGASCAR AND REUNION" if country_2=="MADAGASCAR"
replace country_2 ="MADAGASCAR AND REUNION" if country_2=="REUNION"


**** Manchukuo and Kwantung MEK ****


replace code_1="MEK" if code_1=="MKO"

replace country_1 ="MANCHUKUO AND KWANTUNG" if country_1=="MANCHUKUO"



replace code_2="MEK" if code_2=="MKO"

replace country_2 ="MANCHUKUO AND KWANTUNG" if country_2=="MANCHUKUO"

**** Mauritius and Seychelles - MUS ***

replace code_1="MUS" if code_1=="SYC"

replace country_1 ="MAURITIUS AND SEYCHELLES" if country_1=="MAURITIUS"
replace country_1 ="MAURITIUS AND SEYCHELLES" if country_1=="SEYCHELLES"



replace code_2="MUS" if code_2=="SYC"

replace country_2 ="MAURITIUS AND SEYCHELLES" if country_2=="MAURITIUS"
replace country_2 ="MAURITIUS AND SEYCHELLES" if country_2=="SEYCHELLES"



**** Norway - NOR ****
	
replace code_1="NOR" if code_1=="SPI"

replace country_1 ="NORWAY" if country_1=="SPITZBERGEN"


replace code_2="NOR" if code_2=="SPI"

replace country_2 ="NORWAY" if country_2=="SPITZBERGEN"

**** Palestine - PAL ****


replace code_1="PAL" if code_1=="PTJ"
replace code_1="PAL" if code_1=="TRJ"

replace country_1 ="PALESTINE" if country_1=="PALESTINE AND TRANS-JORDAN"
replace country_1 ="PALESTINE" if country_1=="TRANSJORDAN"



replace code_2="PAL" if code_2=="PTJ"
replace code_2="PAL" if code_2=="TRJ"

replace country_2 ="PALESTINE" if country_2=="PALESTINE AND TRANS-JORDAN"
replace country_2 ="PALESTINE" if country_2=="TRANSJORDAN"

**** Panama - PAN ****


replace code_1="PAN" if code_1=="PIC"

replace code_1="PAN" if code_1=="PCZ"


replace country_1 ="PANAMA" if country_1=="PANAMA (INCLUDING CANAL ZONE)"

replace country_1 ="PANAMA" if country_1=="PANAMA CANAL ZONE"



replace code_2="PAN" if code_2=="PIC"

replace code_2="PAN" if code_2=="PCZ"


replace country_2 ="PANAMA" if country_2=="PANAMA (INCLUDING CANAL ZONE)"

replace country_2 ="PANAMA" if country_2=="PANAMA CANAL ZONE"


**** Philippines - PHL ****

replace code_1="PHL" if code_1=="PHG"
replace code_1="PHL" if code_1=="GUM"

replace country_1 ="PHILIPPINES" if country_1=="PHILIPPINES AND GUAM"
replace country_1 ="PHILIPPINES" if country_1=="GUAM"



replace code_2="PHL" if code_2=="PHG"
replace code_2="PHL" if code_2=="GUM"

replace country_2 ="PHILIPPINES" if country_2=="PHILIPPINES AND GUAM"
replace country_2 ="PHILIPPINES" if country_2=="GUAM"

**** Poland and Danzig  - POD****


replace code_1="POD" if code_1=="POL"
replace code_1="POD" if code_1=="DAN"


replace country_1 ="POLAND AND DANZIG" if country_1=="POLAND"
replace country_1 ="POLAND AND DANZIG" if country_1=="DANZIG"



replace code_2="POD" if code_2=="POL"
replace code_2="POD" if code_2=="DAN"

replace country_2 ="POLAND AND DANZIG" if country_2=="POLAND"
replace country_2 ="POLAND AND DANZIG" if country_2=="DANZIG"



**** Portuguese Asia - PAS ****

replace code_1="PAS" if code_1=="GOA"
replace code_1="PAS" if code_1=="MAC"
replace code_1="PAS" if code_1=="OPS"
replace code_1="PAS" if code_1=="PIS"
replace code_1="PAS" if code_1=="PEI"
replace code_1="PAS" if code_1=="POI"
replace code_1="PAS" if code_1=="POP"
replace code_1="PAS" if code_1=="PTI"


replace country_1 ="PORTUGUESE ASIA" if country_1=="GOA"
replace country_1 ="PORTUGUESE ASIA" if country_1=="MACAO"
replace country_1 ="PORTUGUESE ASIA" if country_1=="OTHER PORTUGUES ASIA"
replace country_1 ="PORTUGUESE ASIA" if country_1=="PORTUGESE POSSESSIONS IN THE INDIAN SEAS"
replace country_1 ="PORTUGUESE ASIA" if country_1=="PORTUGUESE EAST INDIES"
replace country_1 ="PORTUGUESE ASIA" if country_1=="PORTUGUESE INDIA"
replace country_1 ="PORTUGUESE ASIA" if country_1=="PORTUGUESE POSSESSIONS IN THE ORIENT"
replace country_1 ="PORTUGUESE ASIA" if country_1=="PORTUGUESE TIMOR"




replace code_2="PAS" if code_2=="GOA"
replace code_2="PAS" if code_2=="MAC"
replace code_2="PAS" if code_2=="OPS"
replace code_2="PAS" if code_2=="PIS"
replace code_2="PAS" if code_2=="PEI"
replace code_2="PAS" if code_2=="POI"
replace code_2="PAS" if code_2=="POP"
replace code_2="PAS" if code_2=="PTI"


replace country_2 ="PORTUGUESE ASIA" if country_2=="GOA"
replace country_2 ="PORTUGUESE ASIA" if country_2=="MACAO"
replace country_2 ="PORTUGUESE ASIA" if country_2=="OTHER PORTUGUES ASIA"
replace country_2 ="PORTUGUESE ASIA" if country_2=="PORTUGESE POSSESSIONS IN THE INDIAN SEAS"
replace country_2 ="PORTUGUESE ASIA" if country_2=="PORTUGUESE EAST INDIES"
replace country_2 ="PORTUGUESE ASIA" if country_2=="PORTUGUESE INDIA"
replace country_2 ="PORTUGUESE ASIA" if country_2=="PORTUGUESE POSSESSIONS IN THE ORIENT"
replace country_2 ="PORTUGUESE ASIA" if country_2=="PORTUGUESE TIMOR"


**** Portugal - PRT ****

replace code_1="PRT" if code_1=="AZO"
replace code_1="PRT" if code_1=="AZM"
replace code_1="PRT" if code_1=="MAD"


replace country_1 ="PORTUGAL" if country_1=="AZORES"
replace country_1 ="PORTUGAL" if country_1=="AZORES AND MADEIRA"
replace country_1 ="PORTUGAL" if country_1=="MADEIRA"



replace code_2="PRT" if code_2=="AZO"
replace code_2="PRT" if code_2=="AZM"
replace code_2="PRT" if code_2=="MAD"


replace country_2 ="PORTUGAL" if country_2=="AZORES"
replace country_2 ="PORTUGAL" if country_2=="AZORES AND MADEIRA"
replace country_2 ="PORTUGAL" if country_2=="MADEIRA"

**** Portuguese Africa PAF ****

replace code_1="PAF" if code_1=="CAV"
replace code_1="PAF" if code_1=="MOZ"
replace code_1="PAF" if code_1=="OPA"
replace code_1="PAF" if code_1=="PEA"
replace code_1="PAF" if code_1=="POG"
replace code_1="PAF" if code_1=="PWA"
replace code_1="PAF" if code_1=="STO"
replace code_1="PAF" if code_1=="STP"


replace country_1 ="PORTUGUESE AFRICA" if country_1=="CAPE VERDE"
replace country_1 ="PORTUGUESE AFRICA" if country_1=="MOZAMBIQUE"
replace country_1 ="PORTUGUESE AFRICA" if country_1=="OTHER PORTUGUESE AFRICA"
replace country_1 ="PORTUGUESE AFRICA" if country_1=="PORTUGUESE EAST AFRICA"
replace country_1 ="PORTUGUESE AFRICA" if country_1=="PORTUGUESE GUINEA"
replace country_1 ="PORTUGUESE AFRICA" if country_1=="PORTUGUESE WEST AFRICA"
replace country_1 ="PORTUGUESE AFRICA" if country_1=="SAO THOME"
replace country_1 ="PORTUGUESE AFRICA" if country_1=="SAO THOME ET PRINCIPE"




replace code_2="PAF" if code_2=="CAV"
replace code_2="PAF" if code_2=="MOZ"
replace code_2="PAF" if code_2=="OPA"
replace code_2="PAF" if code_2=="PEA"
replace code_2="PAF" if code_2=="POG"
replace code_2="PAF" if code_2=="PWA"
replace code_2="PAF" if code_2=="STO"
replace code_2="PAF" if code_2=="STP"


replace country_2 ="PORTUGUESE AFRICA" if country_2=="CAPE VERDE"
replace country_2 ="PORTUGUESE AFRICA" if country_2=="MOZAMBIQUE"
replace country_2 ="PORTUGUESE AFRICA" if country_2=="OTHER PORTUGUESE AFRICA"
replace country_2 ="PORTUGUESE AFRICA" if country_2=="PORTUGUESE EAST AFRICA"
replace country_2 ="PORTUGUESE AFRICA" if country_2=="PORTUGUESE GUINEA"
replace country_2 ="PORTUGUESE AFRICA" if country_2=="PORTUGUESE WEST AFRICA"
replace country_2 ="PORTUGUESE AFRICA" if country_2=="SAO THOME"
replace country_2 ="PORTUGUESE AFRICA" if country_2=="SAO THOME ET PRINCIPE"




**** SAMOA - WSM ****


replace code_1="WSM" if code_1=="AOC"
replace code_1="WSM" if code_1=="ASO"

replace country_1 ="SAMOA" if country_1=="AMERICAN OCEANIA"
replace country_1 ="SAMOA" if country_1=="AMERICAN SAMOA"



replace code_2="WSM" if code_2=="AOC"
replace code_2="WSM" if code_2=="ASO"

replace country_2 ="SAMOA" if country_2=="AMERICAN OCEANIA"
replace country_2 ="SAMOA" if country_2=="AMERICAN SAMOA"


**** South Africa - ZAF ****

replace code_1="ZAF" if code_1=="BAO"
replace code_1="ZAF" if code_1=="BEC"
replace code_1="ZAF" if code_1=="BBS"
replace code_1="ZAF" if code_1=="SWZ"

replace country_1 ="SOUTH AFRICA" if country_1=="BASUTOLAND"
replace country_1 ="SOUTH AFRICA" if country_1=="BECHUNNALAND PROTECTORATE"
replace country_1 ="SOUTH AFRICA" if country_1=="BECHUNNALAND PROTECTORATE, BASUTOLAND, AND SWAZILAND"
replace country_1 ="SOUTH AFRICA" if country_1=="SWAZILAND"


replace code_2="ZAF" if code_2=="BAO"
replace code_2="ZAF" if code_2=="BEC"
replace code_2="ZAF" if code_2=="BBS"
replace code_2="ZAF" if code_2=="SWZ"

replace country_2 ="SOUTH AFRICA" if country_2=="BASUTOLAND"
replace country_2 ="SOUTH AFRICA" if country_2=="BECHUNNALAND PROTECTORATE"
replace country_2 ="SOUTH AFRICA" if country_2=="BECHUNNALAND PROTECTORATE, BASUTOLAND, AND SWAZILAND"
replace country_2 ="SOUTH AFRICA" if country_2=="SWAZILAND"



**** SPAIN - ESP ****

replace code_1="ESP" if code_1=="CAI"
replace code_1="ESP" if code_1=="CEU"
replace code_1="ESP" if code_1=="MEL"

replace country_1 ="SPAIN" if country_1=="CANARIES"
replace country_1 ="SPAIN" if country_1=="CEUTA"
replace country_1 ="SPAIN" if country_1=="MELILLA"



replace code_2="ESP" if code_2=="CAI"
replace code_2="ESP" if code_2=="CEU"
replace code_2="ESP" if code_2=="MEL"

replace country_2 ="SPAIN" if country_2=="CANARIES"
replace country_2 ="SPAIN" if country_2=="CEUTA"
replace country_2 ="SPAIN" if country_2=="MELILLA"

**** Spanish North Africa SNA ****

replace code_1="SNA" if code_1=="FEZ"
replace code_1="SNA" if code_1=="SMO"
replace code_1="SNA" if code_1=="FMC"


replace country_1 ="SPANISH NORTH AFRICA" if country_1=="SPANISH FEZ"
replace country_1 ="SPANISH NORTH AFRICA" if country_1=="SPANISH MOROCCO"
replace country_1 ="SPANISH NORTH AFRICA" if country_1=="SPANISH MOROCCO AND CANARY ISLANDS"



replace code_2="SNA" if code_2=="FEZ"
replace code_2="SNA" if code_2=="SMO"
replace code_2="SNA" if code_2=="FMC"


replace country_2 ="SPANISH NORTH AFRICA" if country_2=="SPANISH FEZ"
replace country_2 ="SPANISH NORTH AFRICA" if country_2=="SPANISH MOROCCO"
replace country_2 ="SPANISH NORTH AFRICA" if country_2=="SPANISH MOROCCO AND CANARY ISLANDS"

**** Spanish West Africa SWF ****

replace code_1="SWF" if code_1=="RDO"
replace code_1="SWF" if code_1=="SGU"
replace code_1="SWF" if code_1=="SEQ"

replace country_1 ="SPANISH WEST AFRICA" if country_1=="RIO DE ORO"
replace country_1 ="SPANISH WEST AFRICA" if country_1=="SPANISH GUINEA"
replace country_1 ="SPANISH WEST AFRICA" if country_1=="SPANISH WEST EQUATORIAL AFRICA"



replace code_2="SWF" if code_2=="RDO"
replace code_2="SWF" if code_2=="SGU"
replace code_2="SWF" if code_2=="SEQ"

replace country_2 ="SPANISH WEST AFRICA" if country_2=="RIO DE ORO"
replace country_2 ="SPANISH WEST AFRICA" if country_2=="SPANISH GUINEA"
replace country_2 ="SPANISH WEST AFRICA" if country_2=="SPANISH WEST EQUATORIAL AFRICA"


**** Switzerland - CHE ****

	
replace code_1="CHE" if code_1=="LIE"

replace country_1 ="SWITZERLAND" if country_1=="LIECHTENSTEIN"



replace code_2="CHE" if code_2=="LIE"

replace country_2 ="SWITZERLAND" if country_2=="LIECHTENSTEIN"
**** Syria SYR *** check I think Syria is somewhere else as well or was that Lebanon???

replace code_1="SYR" if code_1=="FSY"
replace code_1="SYR" if code_1=="SYL"


replace country_1 ="SYRIA" if country_1=="FRENCH SYRIA"
replace country_1 ="SYRIA" if country_1=="SYRIA LEBANON"


replace code_2="SYR" if code_2=="FSY"
replace code_2="SYR" if code_2=="SYL"


replace country_2 ="SYRIA" if country_2=="FRENCH SYRIA"
replace country_2 ="SYRIA" if country_2=="SYRIA LEBANON"


**** Turkey - TUR ****
replace code_1="TUR" if code_1=="AMI"

replace country_1 ="TURKEY" if country_1=="ASIA MINOR"


replace code_2="TUR" if code_2=="AMI"

replace country_2 ="TURKEY" if country_2=="ASIA MINOR"

**** UNITED KINGDOM - GBR ****
replace code_1="GBR" if code_1=="CHA"
replace code_1="GBR" if code_1=="ENG"
replace code_1="GBR" if code_1=="NIR"


replace country_1 ="UNITED KINGDOM" if country_1=="CHANNEL ISLANDS"
replace country_1 ="UNITED KINGDOM" if country_1=="ENGLAND"
replace country_1 ="UNITED KINGDOM" if country_1=="GREAT BRITAIN"
replace country_1 ="UNITED KINGDOM" if country_1=="NORTHERN IRELAND"



replace code_2="GBR" if code_2=="CHA"
replace code_2="GBR" if code_2=="ENG"
replace code_2="GBR" if code_2=="NIR"


replace country_2 ="UNITED KINGDOM" if country_2=="CHANNEL ISLANDS"
replace country_2 ="UNITED KINGDOM" if country_2=="ENGLAND"
replace country_2 ="UNITED KINGDOM" if country_2=="GREAT BRITAIN"
replace country_2 ="UNITED KINGDOM" if country_2=="NORTHERN IRELAND"
**** Uruguay and Paraguay ****


replace code_1="UPA" if code_1=="URY"
replace code_1="UPA" if code_1=="PRY"

replace country_1 ="URUGUAY AND PARAGUAY" if country_1=="URUGUAY"
replace country_1 ="URUGUAY AND PARAGUAY" if country_1=="PARAGUAY"


replace code_2="UPA" if code_2=="URY"
replace code_2="UPA" if code_2=="PRY"

replace country_2 ="URUGUAY AND PARAGUAY" if country_2=="URUGUAY"
replace country_2 ="URUGUAY AND PARAGUAY" if country_2=="PARAGUAY"



**** USA ****


replace code_1="USA" if code_1=="ALA"

replace country_1 ="UNITED STATES OF AMERICA" if country_1=="ALASKA"


replace code_2="USA" if code_2=="ALA"

replace country_2 ="UNITED STATES OF AMERICA" if country_2=="ALASKA"

**** Venezuela and Guiana ****


replace code_1="VEG" if code_1=="VEN"
replace code_1="VEG" if code_1=="GUY"

replace country_1 ="VENEZUELA AND GUIANA" if country_1=="VENEZUELA"
replace country_1 ="VENEZUELA AND GUIANA" if country_1=="GUIANA"


replace code_2="VEG" if code_2=="VEN"
replace code_2="VEG" if code_2=="GUY"

replace country_2 ="VENEZUELA AND GUIANA" if country_2=="VENEZUELA"
replace country_2 ="VENEZUELA AND GUIANA" if country_2=="GUIANA"


**** Virgin Islands ****

replace code_1="UVI" if code_1=="AMA"
replace code_1="UVI" if code_1=="STX"
replace code_1="UVI" if code_1=="UWI"


replace country_1 ="VIRGIN ISLANDS" if country_1=="AMERICAN ANTILLES"
replace country_1 ="VIRGIN ISLANDS" if country_1=="ST CROIX"
replace country_1 ="VIRGIN ISLANDS" if country_1=="US VIRGIN ISLANDS"
replace country_1 ="VIRGIN ISLANDS" if country_1=="US WEST INDIES"


replace code_2="UVI" if code_2=="AMA"
replace code_2="UVI" if code_2=="STX"
replace code_2="UVI" if code_2=="UWI"


replace country_2 ="VIRGIN ISLANDS" if country_2=="AMERICAN ANTILLES"
replace country_2 ="VIRGIN ISLANDS" if country_2=="ST CROIX"
replace country_2 ="VIRGIN ISLANDS" if country_2=="US VIRGIN ISLANDS"
replace country_2 ="VIRGIN ISLANDS" if country_2=="US WEST INDIES"

**** Yugoslavia and Albania ****



replace code_1="YUA" if code_1=="YUG"
replace code_1="YUA" if code_1=="ALB"


replace country_1 ="YUGOSLAVIA AND ALBANIA" if country_1=="YUGOSLAVIA"
replace country_1 ="YUGOSLAVIA AND ALBANIA" if country_1=="ALBANIA"


replace code_2="YUA" if code_2=="YUG"
replace code_2="YUA" if code_2=="ALB"

replace country_2 ="YUGOSLAVIA AND ALBANIA" if country_2=="YUGOSLAVIA"
replace country_2 ="YUGOSLAVIA AND ALBANIA" if country_2=="ALBANIA"


destring sov1938_1 sov1938_2, replace




collapse (sum)  exports_1 exports_2 exportsGFD_1 exportsGFD_2 (mean) missing_imp missing_exp rate_gfd_1 rate_gfd_2 (max) sov1938_1 sov1938_2, by(code_1 code_2 country_1 country_2 year quarter)




generate xrate = rate_gfd_1/rate_gfd_2 

tab country_1

tab country_2
 
tab code_1

tab code_2

replace exports_1 = . if missing_exp==1

replace exports_2 = . if missing_imp==1

replace exportsGFD_1 = . if missing_exp == 1

replace exportsGFD_2 = . if missing_imp == 1


sum



****step 1: no autarky principle: if you don't have any positive exports to any countries, 
***********then the zeros must be missings! 



count if exportsGFD_1 == 0 & exportsGFD_2 == 0

count if exportsGFD_1 == 0 & exportsGFD_2 == .

count if exportsGFD_1 == . & exportsGFD_2 == 0

gen byte posiflow = exportsGFD_1>0 & exportsGFD_1<.

egen numpartners =sum(posiflow), by(code_1 year quarter)

sum exportsGFD_1 if numpartners==0 

replace exportsGFD_1 = . if numpartners==0

drop posiflow numpartners

*** code changes 409 observations from 0 to missing




*****step 2: apply no autarky principle to imports

gen byte posiflow = exportsGFD_2>0 & exportsGFD_2<.

egen numpartners =sum(posiflow), by(code_2 year quarter)

sum exportsGFD_2 if numpartners==0 

replace exportsGFD_2 = . if numpartners==0

drop posiflow numpartners


*** code changes 217 observations from 0 to missing




*** Now develop one measure of flows. Use import flows unless they seem too small or are missing

*** If import flows are too small or missing use export flows plus 10%

gen flow_lfr = exportsGFD_2

count if flow_lfr<0.001

count if flow_lfr<0.001 & flow_lfr>0

replace flow_lfr = 1.1*exportsGFD_1 if 1.1*exportsGFD_1>exportsGFD_2 & exportsGFD_1!=.

replace flow_lfr = 1.1*exportsGFD_1 if flow_lfr==. & exportsGFD_1!=0  

count if flow_lfr<0.001

count if flow_lfr<0.001 & flow_lfr>0

label var flow_lfr "larger flow report preferred"


gen flow_icr = exportsGFD_2

replace flow_icr = 1.1*exportsGFD_1 if (flow_icr==. | flow_icr==0) & exportsGFD_1<. &exportsGFD_1>0

label var flow_icr "import country report preferred"

count if flow_icr<0.001

count if flow_icr<0.001 & flow_icr>0

compare flow_lfr flow_icr

gen double flow = flow_lfr

drop if flow==.

gen byte validmirror =  exportsGFD_2<. & exportsGFD_1<.

label var validmirror "both mirror flows are valid"

gen byte posiflow = flow>0

egen numpartners_m =sum(posiflow), by(code_2 year quarter)

sum flow if numpartners_m==0

egen numpartners_x =sum(posiflow), by(code_1 year quarter)

sum flow if numpartners_x==0

gen byte noexports = numpartners_x==0

label var noexports "country-year-quarter with no exports>0 to any dest"

count if noexports==1

drop flow_* num* posiflow noexports 





****************************************************************
count
count if flow==0
******





*** Get rid of countries with very small flows  


egen exports =sum(flow), by(code_1 year quarter)

egen imports =sum(flow), by(code_2 year quarter)


*** If there are zero exports to anywhere then these are missing values

replace flow = . if exports==0

replace flow = . if imports==0




*** If flows are less than $1000 replace them with zeros (Head and Mayer did this for flows less than $5000, for data 1948-2006)

replace flow = 0 if flow < 1000




* sort data
sort code_1 code_2 year quarter

* generate unique pair identifyer

egen pair = group (code_1 code_2)

* generate combined year/quarter variable 

gen y_q =yq(year,quarter)
format y_q %tq


sort pair y_q



**** Banking crisis *****
*** exact dates from Bernanke and James (1991)
*** coded for 1 year if no clear end date

gen crisis_1=0
gen crisis_2=0

* Austria
replace crisis_1=1 if country_1=="AUSTRIA" & -115<=y_q & y_q<=-108
replace crisis_2=1 if country_2=="AUSTRIA" & -115<=y_q & y_q<=-108

*Argentina
replace crisis_1=1 if country_1=="ARGENTINA" & -115<=y_q & y_q<=-112
replace crisis_2=1 if country_2=="ARGENTINA" & -115<=y_q & y_q<=-112

replace crisis_1=1 if country_1=="ARGENTINA" & -102<=y_q & y_q<=-99
replace crisis_2=1 if country_2=="ARGENTINA" & -102<=y_q & y_q<=-99

*Belgium

replace crisis_1=1 if country_1=="BELGIUM AND LUXEMBURG" & -115<=y_q & y_q<=-111
replace crisis_2=1 if country_2=="BELGIUM AND LUXEMBURG" & -115<=y_q & y_q<=-111

replace crisis_1=1 if country_1=="BELGIUM AND LUXEMBURG" & -104<=y_q & y_q<=-99
replace crisis_2=1 if country_2=="BELGIUM AND LUXEMBURG" & -104<=y_q & y_q<=-99


*Estonia
replace crisis_1=1 if country_1=="ESTONIA" & -114<=y_q & y_q<=-110
replace crisis_2=1 if country_2=="ESTONIA" & -114<=y_q & y_q<=-110

*France
replace crisis_1=1 if country_1=="FRANCE" & -117<=y_q & y_q<=-109
replace crisis_2=1 if country_2=="FRANCE" & -117<=y_q & y_q<=-109

*Germany
replace crisis_1=1 if country_1=="GERMANY" & -115<=y_q & y_q<=-109
replace crisis_2=1 if country_2=="GERMANY" & -115<=y_q & y_q<=-109

*Hungary
replace crisis_1=1 if country_1=="HUNGARY" & -114<=y_q & y_q<=-111
replace crisis_2=1 if country_2=="HUNGARY" & -114<=y_q & y_q<=-111

*Italy
replace crisis_1=1 if country_1=="ITALY" & -115<=y_q & y_q<=-109
replace crisis_2=1 if country_2=="ITALY" & -115<=y_q & y_q<=-109

*Japan
replace crisis_1=1 if country_1=="JAPAN" & -131<=y_q & y_q<=-128
replace crisis_2=1 if country_2=="JAPAN" & -131<=y_q & y_q<=-128

*Latvia
replace crisis_1=1 if country_1=="LATVIA" & -114<=y_q & y_q<=-111
replace crisis_2=1 if country_2=="LATVIA" & -114<=y_q & y_q<=-111

*Mexico
replace crisis_1=1 if country_1=="MEXICO" & -114<=y_q & y_q<=-111
replace crisis_2=1 if country_2=="MEXICO" & -114<=y_q & y_q<=-111

*Poland
replace crisis_1=1 if country_1=="POLAND AND DANZIG" & -115<=y_q & y_q<=-111
replace crisis_2=1 if country_2=="POLAND AND DANZIG" & -115<=y_q & y_q<=-111

*Romania
replace crisis_1=1 if country_1=="ROMANIA" & -114<=y_q & y_q<=-110
replace crisis_2=1 if country_2=="ROMANIA" & -114<=y_q & y_q<=-110

*Sweden
replace crisis_1=1 if country_1=="SWEDEN" & -112<=y_q & y_q<=-108
replace crisis_2=1 if country_2=="SWEDEN" & -112<=y_q & y_q<=-108

*USA
replace crisis_1=1 if country_1=="UNITED STATES OF AMERICA" & -117<=y_q & y_q<=-108
replace crisis_2=1 if country_2=="UNITED STATES OF AMERICA" & -117<=y_q & y_q<=-108


**** annual data from mayer.do code (Kevin) country groups updated
**** some countries in here in addition to the monthly dates listed above if there were additional crisis dates in the annual data

*British Oceania (Australia)
replace crisis_1=1 if country_1=="BRITISH OCEANIA" & year==1931 
replace crisis_2=1 if country_2=="BRITISH OCEANIA" & year==1931

replace crisis_1=1 if country_1=="BRITISH OCEANIA" & year==1932 
replace crisis_2=1 if country_2=="BRITISH OCEANIA" & year==1932

*Brazil
replace crisis_1=1 if country_1=="BRAZIL" & year==1926
replace crisis_2=1 if country_2=="BRAZIL" & year==1926

replace crisis_1=1 if country_1=="BRAZIL" & year==1929
replace crisis_2=1 if country_2=="BRAZIL" & year==1929

*Chile
replace crisis_1=1 if country_1=="CHILE" & year==1926
replace crisis_2=1 if country_2=="CHILE" & year==1926

*China
replace crisis_1=1 if country_1=="CHINA" & year==1925
replace crisis_2=1 if country_2=="CHINA" & year==1925

replace crisis_1=1 if country_1=="CHINA" & year==1931 
replace crisis_2=1 if country_2=="CHINA" & year==1931

replace crisis_1=1 if country_1=="CHINA" & year==1934 
replace crisis_2=1 if country_2=="CHINA" & year==1934

replace crisis_1=1 if country_1=="CHINA" & year==1935 
replace crisis_2=1 if country_2=="CHINA" & year==1935

replace crisis_1=1 if country_1=="CHINA" & year==1936 
replace crisis_2=1 if country_2=="CHINA" & year==1936

replace crisis_1=1 if country_1=="CHINA" & year==1937 
replace crisis_2=1 if country_2=="CHINA" & year==1937

*Denmark
replace crisis_1=1 if country_1=="DENMARK" & year==1931 
replace crisis_2=1 if country_2=="DENMARK" & year==1931

*Finland
replace crisis_1=1 if country_1=="FINLAND" & year==1931 
replace crisis_2=1 if country_2=="FINLAND" & year==1931

*Greece
replace crisis_1=1 if country_1=="GREECE" & year==1931 
replace crisis_2=1 if country_2=="GREECE" & year==1931

*India
replace crisis_1=1 if country_1=="INDIA" & year==1929
replace crisis_2=1 if country_2=="INDIA" & year==1929

replace crisis_1=1 if country_1=="INDIA" & year==1930 
replace crisis_2=1 if country_2=="INDIA" & year==1930

replace crisis_1=1 if country_1=="INDIA" & year==1931 
replace crisis_2=1 if country_2=="INDIA" & year==1931

*Japan
replace crisis_1=1 if country_1=="JAPAN" & year==1928
replace crisis_2=1 if country_2=="JAPAN" & year==1928

*Mexico - listed annually in addition to the crisis included above
replace crisis_1=1 if country_1=="MEXICO" & year==1929
replace crisis_2=1 if country_2=="MEXICO" & year==1929

replace crisis_1=1 if country_1=="MEXICO" & year==1930 
replace crisis_2=1 if country_2=="MEXICO" & year==1930

*Norway
replace crisis_1=1 if country_1=="NORWAY" & year==1931 
replace crisis_2=1 if country_2=="NORWAY" & year==1931

*Portugal
replace crisis_1=1 if country_1=="PORTUGAL" & year==1931 
replace crisis_2=1 if country_2=="PORTUGAL" & year==1931

replace crisis_1=1 if country_1=="PORTUGAL" & year==1932
replace crisis_2=1 if country_2=="PORTUGAL" & year==1932

*Spain
replace crisis_1=1 if country_1=="SPAIN" & year==1925
replace crisis_2=1 if country_2=="SPAIN" & year==1925

replace crisis_1=1 if country_1=="SPAIN" & year==1931 
replace crisis_2=1 if country_2=="SPAIN" & year==1931

*Sweden
replace crisis_1=1 if country_1=="SWEDEN" & year==1931 
replace crisis_2=1 if country_2=="SWEDEN" & year==1931


*Switzerland
replace crisis_1=1 if country_1=="SWITZERLAND" & year==1931 
replace crisis_2=1 if country_2=="SWITZERLAND" & year==1931

*Turkey
replace crisis_1=1 if country_1=="TURKEY" & year==1931 
replace crisis_2=1 if country_2=="TURKEY" & year==1931


gen crisis = (crisis_1 == 1 & crisis_2 == 1)



foreach i in  _1 _2 {


*** Generate UK empire dummy ****


gen ukempire`i' = 0

replace ukempire`i' = 1 if country`i'=="ARABIA"

replace ukempire`i' = 1 if country`i'=="CANADA"

replace ukempire`i' = 1 if country`i'=="IRELAND"

replace ukempire`i' = 1 if country`i'=="ASCENSION FALKLANDS STHELENA"

replace ukempire`i' = 1 if country`i'=="BRITISH EAST AFRICA"

replace ukempire`i' = 1 if country`i'=="BRITISH EAST INDIES"

replace ukempire`i' = 1 if country`i'=="BRITISH MEDITERRANEAN" 

replace ukempire`i' = 1 if country`i'=="BRITISH OCEANIA" 

replace ukempire`i' = 1 if country`i'=="BRITISH SOUTHERN AFRICA" 

replace ukempire`i' = 1 if country`i'=="BRITISH SUDAN" 

replace ukempire`i' = 1 if country`i'=="BRITISH WEST AFRICA" 

replace ukempire`i' = 1 if country`i'=="BRITISH WEST INDIES"

replace ukempire`i' = 1 if country`i'=="INDIA"

replace ukempire`i' = 1 if country`i'=="MAURITIUS AND SEYCHELLES"

replace ukempire`i' = 1 if country`i'=="PALESTINE"

replace ukempire`i' = 1 if country`i'=="SOUTH AFRICA"

replace ukempire`i' = 1 if country`i'=="UNITED KINGDOM"

replace ukempire`i' = 1 if country`i'=="IRAN IRAQ AND AFGHANISTAN"





*** French Empire


gen frenchempire`i' = 0


replace frenchempire`i' = 1 if country`i' == "FRANCE"

replace frenchempire`i' = 1 if country`i' == "FRENCH EAST AFRICA"

replace frenchempire`i' = 1 if country`i' == "FRENCH EAST INDIES"

replace frenchempire`i' = 1 if country`i' == "FRENCH NORTH AFRICA"

replace frenchempire`i' = 1 if country`i' == "FRENCH OCEANIA"

replace frenchempire`i' = 1 if country`i' == "FRENCH WEST AFRICA"

replace frenchempire`i' = 1 if country`i' == "FRENCH WEST INDIES"

replace frenchempire`i' = 1 if country`i' == "MADAGASCAR AND REUNION"

replace frenchempire`i' = 1 if country`i' == "SYRIA"



*** Dutch Empire

gen dutchempire`i' = 0

replace dutchempire`i' = 1 if country`i' == "NETHERLANDS"

replace dutchempire`i' = 1 if country`i' == "DUTCH EAST INDIES"

replace dutchempire`i' = 1 if country`i' == "DUTCH WEST INDIES"


*** Portuguese Empire

gen portempire`i' = 0

replace portempire`i' = 1 if country`i' == "PORTUGAL"

replace portempire`i' = 1 if country`i' == "PORTUGUESE AFRICA"

replace portempire`i' = 1 if country`i' == " PORTUGUESE ASIA"


*** Belgian Empire

gen belgianempire`i' = 0

replace belgianempire`i' = 1 if country`i' == "BELGIUM AND LUXEMBURG"

replace belgianempire`i' = 1 if country`i' == "BELGIAN AFRICA"



*** Italian Empire

gen italianempire`i' = 0

replace italianempire`i' = 1 if country`i' == "ETHIOPIA" & year >= 1936

replace italianempire`i' = 1 if country`i' == "ITALY"

replace italianempire`i' = 1 if country`i' == "ITALIAN AFRICA"

*** American Empire

gen usempire`i' = 0

replace usempire`i' = 1 if country`i' == " PHILIPPINES"

replace usempire`i' = 1 if country`i' == "PUERTO RICO"

replace usempire`i' = 1 if country`i' == "UNITED STATES OF AMERICA"

replace usempire`i' = 1 if country`i' == "VIRGIN ISLANDS"





*** Sterling area 

gen sterling`i' = 0

***replace sterling`i' = 1 if country`i' == "Argentina" & year >= 1934

*** Stewart 1937 p. 183 
*** Cairncross and Eichengreen 2003, p. 24 also say not: a peg, but either multiple exchange rates or exchange controls
*** On the other hand the Economist clearly considered Argentina to be a member at the time
*** Zupnick also considers Argentina and Japan not to be members of the "sterling bloc" despite pegging to sterling
*** Stewart 1936, pp. 20-21: In Februaty 1934 it pegs to sterling. However, there are multiple exchange rates.
*** This source describes it as part of the sterling fringe: https://library.cqpress.com/cqresearcher/document.php?id=cqresrre1946032800


replace sterling`i' = 1 if country`i' == "BRITISH OCEANIA" & year >= 1932

*** Australian pound fixed against sterling in December 1931: Drummond pp. 101-2

replace sterling`i' = 1 if country`i' == "BRITISH WEST INDIES" & year >= 1931

*** clauson 1944, pp. 14-5, Shannon 1952, pp. 329-30

replace sterling`i' = 1 if country`i' == "ARABIA" & year >= 1931

*** The Gulf economies used rupees

replace sterling`i' = 1 if country`i' == "BRITISH WEST INDIES" & year >= 1931

*** clauson 1944, pp. 14-5, Shannon 1952, pp. 330

*** Belize (British Honduras) was on the dollar

replace sterling`i' = 1 if country`i' == "BRITISH WEST  INDIES" & year >= 1931

*** clauson 1944, pp. 14-5, Shannon 1952, pp. 331

*** replace sterling`i' = 1 if country`i' == "Bolivia" & year >= 1935

*** Cairncross and Eichengreen 2003, p. 24  say not: a peg, but either multiple exchange rates or exchange controls
*** This source describes it as part of the sterling fringe: https://library.cqpress.com/cqresearcher/document.php?id=cqresrre1946032800



replace sterling`i' = 1 if country`i' == "BRITISH EAST AFRICA" & year >= 1931

replace sterling`i' = 1 if country`i' == "PALESTINE" & year >= 1931

*** clauson 1944, p. 14

replace sterling`i' = 1 if country`i' == "BRITISH SOUTHERN AFRICA" & year >= 1933

*** South Africa doesn’t immediately follow the UK off gold (Drummond p. 75); it only goes off on 28 December 1932 (p. 76).

***  In February 1933 it pegs to sterling (p. 77) and remains at parity until after the war (p. 97)

replace sterling`i' = 1 if country`i' == "BRITISH EAST INDIES" & year >= 1931

*** clauson 1944, p. 18, Shannon 1952, pp. 333, 340
*** It uses the Malayan dollar which was linked to sterling 
 
replace sterling`i' = 1 if country`i' == "BRITISH MEDITERRANEAN" & year >= 1931

*** clauson 1944, pp. 13-4

replace sterling`i' = 1 if country`i' == "DENMARK" & year >= 1933

*** Rooth 1984, p. 221 says Danish crown linked to sterling from February 1933. This was the Kanslergade agreement.

replace sterling`i' = 1 if country`i' == "EGYPT" & year >= 1931

*** Mikesell 1948, pp. 162-3

replace sterling`i' = 1 if country`i' == "ESTONIA" & y_q >= -107

*** Cairncross and Eichengreen 2003, p. 24; Baster 1937, p. 570 (joins September 1933)


replace sterling`i' = 1 if country`i' == "ASCENSION FALKLANDS STHELENA" & year >= 1931

*** clauson 1944, pp. 14, Shannon 1952 pp. 333-4

replace sterling`i' = 1 if country`i' == "BRITISH OCEANIA" & year >= 1934

*** Shannon 1952, p. 334 says Fiji pound, fixed to sterling, was set up in 1933-4
*** According to clauson 1944, p. 16 the legislation was passed in 1933 and the new coin issued in 1934
*** Until then the currency had shadowed the New Zealand currency

replace sterling`i' = 1 if country`i' == "FINLAND" & year >= 1933

*** March 1933: value of markka fixed against sterling and rate remains unchanged until war
*** Haavisto and Jonung, p. 264, in Feinstein, Banking, Currency, and Finance in Europe between the Wars

*** replace sterling`i' = 1 if country`i' == "France" & year >= 1938

*** Drummond: Tripartite declaration, 26 September 1936. “France had joined the sterling area, at least in the sense 
*** that its authorities would henceforth govern their behaviour on the basis of the sterling exchange rate.” (p. 218)
*** On the other hand, “thereafter the franc was devalued several times and was, intermittently, a freely floating 
*** currency.” (p. 203). The franc is devalued in May 1938 (p. 235). After that money flows into France: 
*** with a centre-right government people don’t fear further devaluation (p. 236).

replace sterling`i' = 1 if country`i' == "BRITISH WEST  AFRICA" & year >= 1931

*** Shannon 1952 p. 335

*replace sterling`i' = 1 if country`i' == "Ghana" & year >= 1931

*** Shannon 1952 p. 335


replace sterling`i' = 1 if country`i' == "BRITISH MEDITERRANEAN" & year >= 1931

*** clauson 1944, p. 14

*** replace sterling`i' = 1 if country`i' == "Greece" & year >= 1936
*** Cairncross and Eichengreen 2003, p. 24  say not: a peg, but either multiple exchange rates or exchange controls
*** Lazaretou JEEH 1996 p. 667 says it joined the sterling area in September 1936, having previously joined the gold bloc in June 1933
*** See http://www.jeeh.it/articolo?urn=urn:abi:abi:RIV.JOU:1996;3.647&ev=1
*** This source describes it as part of the sterling fringe: https://library.cqpress.com/cqresearcher/document.php?id=cqresrre1946032800
*** BIS 1937 says they attach themselves to sterling on 29 September 1936



replace sterling`i' = 1 if country`i' == "BRITISH WEST INDIES" & year >= 1931

*** clauson 1944, p. 14

replace sterling`i' = 1 if country`i' == "HONG KONG" & year >= 1935

*** In winter of 1931-2 Hong Kong is not on sterling (p. 14). In 1933 it is still on silver (p. 124). 
** Eventually (p. 252) it adopts a “variant” of a currency board system. When? Answer from Catherine and elsewhere: 1935

replace sterling`i' = 1 if country`i' == "ICELAND" & year >= 1931

*** Thorhallsson and Joenson (2015)


replace sterling`i' = 1 if country`i' == "INDIA" & year >= 1931

*** India goes on to gold in 1927 (p. 29) but was legally fixed to sterling and it stays fixed after 1931

replace sterling`i' = 1 if country`i' == "IRAN IRAQ AND AFGHANISTAN" & year >= 1931

*** Shimizu 1984 p. 260

*** replace sterling`i' = 1 if country`i' == "Iran" & year >= 1936

*** Cairncross and Eichengreen 2003, p. 24
*** This source describes it as part of the sterling fringe: https://library.cqpress.com/cqresearcher/document.php?id=cqresrre1946032800
*** Ilzetzki et al 2017 say it pegged in 1936 but there was a parallel market. 

replace sterling`i' = 1 if country`i' == "IRELAND" & year >= 1931

replace sterling`i' = 1 if country`i' == "BRITISH WEST INDIES" & year >= 1931

*** clauson 1944, p. 14

*** replace sterling`i' = 1 if country`i' == "Japan" & year >= 1933

*** See Zupnick 1955 comment above
*** This source describes it as part of the sterling fringe: https://library.cqpress.com/cqresearcher/document.php?id=cqresrre1946032800
*** BIS 1937: The exchange rate, which has been maintained on sterling by the unofficial operations of the 
*** Yokohama Specie Bank for four years at 1s.2d., showed signs of weakness towards the end of 1936 and in January 1937 exchange 
*** restrictions were imposed largely to prevent heavy semi-speculative imports. 


replace sterling`i' = 1 if country`i' == "ARABIA" & year >= 1931

*** The Gulf economies used rupees

replace sterling`i' = 1 if country`i' == "LATVIA" & y_q >=-94

*** 28/9/1936: Latvia devalues and pegs to sterling (Karnups 2006); Cairncross and Eichengreen 2003, p. 24; BIS 1937

replace sterling`i' = 1 if country`i' == "BRITISH WEST INDIES" & year >= 1931

*** clauson 1944, p. 14,5; Shannon 1952 pp. 339-40

*replace sterling`i' = 1 if country`i' == "Malawi" & year >= 1931

*** Nyasaland: Shannon 1952, p. 344, clauson 1944, p. 14, Hulec 1969 p. 100


replace sterling`i' = 1 if country`i' == "BRITISH MEDITERRANEAN" & year >= 1931

*** clauson 1944, p. 14

replace sterling`i' = 1 if country`i' == "MAURITIUS AND SEYCHELLES" & year >= 1931

*** clauson 1944, p. 17, Shannon 1952 p. 341
*** It was linked to rupee and then (from 1934) to sterling

replace sterling`i' = 1 if country`i' == "BRITISH OCEANIA" & year >= 1933

*** “In New Zealand much the same thing as in Australia happened. 
*** Between October 1928 and late January 1931 the banks raise the price of sterling from just over par to £1.10 New Zealand."
*** In January 1933 the pound is pegged to sterling at a new rate (£1.25). (Drummond)

replace sterling`i' = 1 if country`i' == "BRITISH WEST AFRICA" & year >= 1931

*** Shannon 1952 p. 335


replace sterling`i' = 1 if country`i' == "NORWAY" & year >= 1933

*** De facto peg against sterling from 1933: A Monetary History of Norway, 1816–2016 

replace sterling`i' = 1 if country`i' == "PORTUGAL" & y_q >= -114

*** Portugal immediately pegs to sterling after September 1931. Drummond p. 7

replace sterling`i' = 1 if country`i' == "MAURITIUS AND SEYCHELLES" & year >= 1931

*** clauson 1944, p. 17

replace sterling`i' = 1 if country`i' == "BRITISH WEST AFRICA" & year >= 1931

*** Shannon 1952 p. 335

*replace sterling`i' = 1 if country`i' == "Sri Lanka" & year >= 1931

*** clauson 1944, p. 17

replace sterling`i' = 1 if country`i' == "BRITISH EAST INDIES" & year >= 1931

*** clauson 1944, p. 18, Shannon 1952, pp. 340

replace sterling`i' = 1 if country`i' == "BRITISH SUDAN" & year >= 1931

*** Mikesell 1948, pp. 164

replace sterling`i' = 1 if country`i' == "SWEDEN" & year >= 1933

*** Straumann and Woitek 2009; BIS 1937 p. 75

*replace sterling`i' = 1 if country`i' == "Thailand" & year >= 1932

*** Cairncross and Eichengreen 2003, p. 24
*** BIS 1933 dates the peg to sterling as 11 May 1932
*** Shenoy says the same, so go with that

*** replace sterling`i' = 1 if country`i' == "Turkey" & year >= 1936

*** BIS 1937 says they peg against sterling on 28 September 1936

replace sterling`i' = 1 if country`i' == "UNITED KINGDOM" & year >= 1931

*** replace sterling`i' = 1 if country`i' == "Uruguay" & year >= 1938
*** BIS 1937 says that Uruguay became linked to sterling in autumn 1936

*** Similar category to Argentina and Japan according to Baster 1937 p. 568

replace sterling`i' = 1 if country`i' == "BRITISH WEST INDIES" & year >= 1931

*** clauson 1944, pp. 14-5

*replace sterling`i' = 1 if country`i' == "Zambia" & year >= 1931

*** clauson 1944, p. 14, Shannon 1952, pp. 343, Hulec 1969, p. 100

*replace sterling`i' = 1 if country`i' == "Zimbabwe" & year >= 1931

*** Hulec 1969, p. 100



*** Imperial Preference (July/August 1932)


gen imp_pref`i' = 0

replace imp_pref`i' = 1 if country`i' == "BRITISH OCEANIA" & y_q>-111

replace imp_pref`i' = 1 if country`i' == "SOUTH AFRICA" & y_q>-111

replace imp_pref`i' = 1 if country`i' == "CANADA" & y_q>-111

replace imp_pref`i' = 1 if country`i' == "INDIA" & y_q>-111

* replace imp_pref`i' = 1 if country`i' == "Ireland" & y_q>-111

*replace imp_pref`i' = 1 if country`i' == "New Zealand" & y_q>-111

replace imp_pref`i' = 1 if country`i' == "UNITED KINGDOM" & y_q>-111

*replace imp_pref`i' = 1 if country`i' == "Zimbabwe" & y_q>-111


*** Anglo-Irish Economic War

gen angloirishwar`i' = 0

replace angloirishwar`i' = 1 if country`i' == "IRELAND" & year>=1932 & year <=1938

replace angloirishwar`i' = 1 if country`i' == "UNITED KINGDOM" & year>=1932 & year <=1938




*** German-Polish Trade war



gen germanpolishwar`i' = 0 


replace germanpolishwar`i' = 1 if country`i' == "GERMANY" & y_q>=-139 & y_q <=-102

replace germanpolishwar`i' = 1 if country`i' == "POLAND AND DANZIG" & y_q>=-139 & y_q <=-102

*a German-Polish tariff war. It started in June 1925 and ended in September-October 1934. 
*sources:

*Kruszewski, Charles. "The German-Polish Tariff War (1925-1934) and its Aftermath." Journal of Central European Affairs 3 (1943): 294-315.

*S. Kowal, “Der deutsch-polnische Handel, 1900 bis 2006,” in Interesse und Konflikt: zur
*politischen Ökonomie der deutsch-polnischen Beziehungen, 1900-2007, ed. D. Bingen et al. (2008), 33.




*** Reichsmark

*** Right now this is coded as in Gowa and Hicks

gen reichsmark`i' = 0

replace reichsmark`i' = 1 if country`i' == "AUSTRIA" & year >= 1932

replace reichsmark`i' = 1 if country`i' == "BULGARIA" & year >= 1932

replace reichsmark`i' = 1 if country`i' == "CZECHOSLOVAKIA" & year >= 1932

replace reichsmark`i' = 1 if country`i' == "GERMANY" & year >= 1932

replace reichsmark`i' = 1 if country`i' == "GREECE" & year >= 1932

replace reichsmark`i' = 1 if country`i' == "HUNGARY" & year >= 1932

replace reichsmark`i' = 1 if country`i' == "ROMANIA" & year >= 1932


*** Now gold bloc

gen gold`i' = 0

replace gold`i' = 1 if belgianempire`i' == 1 & year >= 1931 & year <= 1935

replace gold`i' = 1 if frenchempire`i' == 1 & year >= 1931 & year <= 1936

replace gold`i' = 1 if italianempire`i' == 1 & year >= 1931 & year <= 1934

replace gold`i' = 1 if dutchempire`i' == 1 & year >= 1931 & year <= 1936

replace gold`i' = 1 if country`i' == "POLAND AND DANZIG" & year >= 1931 & year <= 1936

replace gold`i' = 1 if country`i' == "SWITZERLAND" & year >= 1931 & year <= 1936



}




*** Italian sanctions
*italy sactions uni directional only affecting exports from Italy

gen italysanctions = 0

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "ANGOLA"  & y_q >=-97 & y_q <=-94
replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "ASCENSION FALKLANDS STHELENA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BELGIAN AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BELGIUM AND LUXEMBURG"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BHUTAN AND NEPAL"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BRITISH EAST AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BRITISH EAST INDIES"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BRITISH MEDITERRANEAN"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BRITISH OCEANIA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BRITISH SOUTHERN AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BRITISH SUDAN"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BRITISH WEST AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BRITISH WEST INDIES"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "BULGARIA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "CAMEROON"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "CANADA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "CENTRAL AMERICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "CUBA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "CZECHOSLOVAKIA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "DENMARK"  & y_q >=-97 & y_q <=-94
replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "DOMINICAN REPUBLIC"  & y_q >=-97 & y_q <=-94


replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "DUTCH EAST INDIES"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "DUTCH WEST INDIES"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "EGYPT"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "EL SALVADOR"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "ESTONIA"   & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "ETHIOPIA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "FINLAND"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "FRANCE"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "FRENCH EAST AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "FRENCH EAST INDIES"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "FRENCH NORTH AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "FRENCH OCEANIA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "FRENCH WEST AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "FRENCH WEST INDIES"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "GERMAN EAST AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "GREECE"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "HAITI"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "HONDURAS"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "HONG KONG"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "INDIA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "IRAN IRAQ AND AFGHANISTAN"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "IRELAND"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "ITALIAN AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "LIBERIA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "LITHUANIA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "MADAGASCAR AND REUNION"   & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "MAURITIUS AND SEYCHELLES" & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "MEXICO"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "MIQUELON AND ST PIERRE ISLANDS"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "NETHERLANDS"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "NEWFOUNDLAND"   & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "NORWAY"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "PALESTINE"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "PHILIPPINES"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "POLAND AND DANZIG"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "PORTUGAL"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "PORTUGUESE AFRICA"   & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "PORTUGUESE ASIA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "PUERTO RICO"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "ROMANIA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "SAMOA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "SIAM"  & y_q >=-97 & y_q <=-94


replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "SOUTH AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "SOVIET UNION"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "SPAIN"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "SPANISH NORTH AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "SPANISH WEST AFRICA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "SWEDEN"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "SYRIA"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "TURKEY"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "UNITED KINGDOM"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "VIRGIN ISLANDS"  & y_q >=-97 & y_q <=-94

replace italysanctions = 1 if country_1 == "ITALY" & country_2 == "YUGOSLAVIA AND ALBANIA"  & y_q >=-97 & y_q <=-94


* include all countries in the Italy sactions except these:  Afghanistan, Albania, Arabia, Argentina, Austria, Bolivia, Brazil, Chile, China, Costa Rica, Ecuador, Germany, Japan, Guatemala, Iceland, Yemen, Manchukuo, Morocco, Nicaragua, Panama, Paraguay, Peru, United States of America, Switzerland, Hungary, Uruguay, Venezuela. 

 




*** If there are no flows between the UK and a member of the British Empire this is probably wrong

count if flow == 0 & ukempire_1 == 1 & country_2 == "UNITED KINGDOM"

*** There were two such flows - ARABIA 1925Q1 & 1935Q3

drop if flow == 0 & ukempire_1 == 1 & country_2 == "UNITED KINGDOM"

count if flow == 0 & ukempire_2 == 1 & country_1 == "UNITED KINGDOM"

*** There were no such flows


*** If there are no flows between France and a member of the French Empire this is probably wrong

count if flow == 0 & frenchempire_1 == 1 & country_2 == "FRANCE"

*** There were no such flows

count if flow == 0 & frenchempire_2 == 1 & country_1 == "FRANCE"

*** There were no such flows


*** If there are no flows between the Netherlands and a member of the Dutch Empire this is probably wrong

count if flow == 0 & dutchempire_1 == 1 & country_2 == "NETHERLANDS"

*** There were no such flows

count if flow == 0 & dutchempire_2 == 1 & country_1 == "NETHERLANDS"

*** There were no such flows


*** If there are no flows between Portugal and a member of the Portguese Empire this is probably wrong

count if flow == 0 & portempire_1 == 1 & country_2 == "PORTUGAL"

*** There were no such flows

count if flow == 0 & portempire_2 == 1 & country_1 == "PORTUGAL"

*** There were no such flows


*** If there are no flows between Belgium and a member of the Belgian Empire this is probably wrong

count if flow == 0 & belgianempire_1 == 1 & country_2 == "BELGIUM AND LUXEMBURG"

*** There were no such flows

count if flow == 0 & belgianempire_2 == 1 & country_1 == "BELGIUM AND LUXEMBURG"

*** There were no such flows


*** If there are no flows between Italy and a member of the Italian Empire this is probably wrong

count if flow == 0 & italianempire_1 == 1 & country_2 == "ITALY"

*** There were no such flows

count if flow == 0 & italianempire_2 == 1 & country_1 == "ITALY"

*** There were no such flows



*** If there are no flows between the USA and a member of the American Empire this is probably wrong

count if flow == 0 & usempire_1 == 1 & country_2 == "UNITED STATES OF AMERICA"

*** There were 5 such flows - VIRGIN ISLANDS 1935Q1 1935Q2 1935Q3 1935Q4 1936Q1

drop if flow == 0 & usempire_1 == 1 & country_2 == "UNITED STATES OF AMERICA"


count if flow == 0 & usempire_2 == 1 & country_1 == "UNITED STATES OF AMERICA"

*** There were no such flows





gen ukempire = (ukempire_1 == 1 & ukempire_2 == 1)

gen sterling = (sterling_1 == 1 & sterling_2 == 1)

gen frenchempire = (frenchempire_1 == 1 & frenchempire_2 == 1)

gen dutchempire = (dutchempire_1 == 1 & dutchempire_2==1)

gen portempire = (portempire_1 == 1 & portempire_2==1)

gen belgianempire = (belgianempire_1 == 1 & belgianempire_2 == 1)

gen italianempire = (italianempire_1 == 1 & italianempire_2 == 1)

gen usempire = (usempire_1 == 1 & usempire_2 == 1)


gen imp_pref = (imp_pref_1 == 1 & imp_pref_2 == 1)

gen angloirishwar = (angloirishwar_1 == 1 & angloirishwar_2 == 1)

gen germanpolishwar = (germanpolishwar_1 == 1 & germanpolishwar_2 == 1)


gen reichsmark = (reichsmark_1 == 1 & reichsmark_2 == 1)

gen gold = (gold_1 == 1 & gold_2 == 1)





gen rtaa = 0

replace rtaa = 1 if country_1 == "CUBA" & country_2 == "UNITED STATES OF AMERICA" & year > 1933

replace rtaa = 1 if country_2 == "CUBA" & country_1 == "UNITED STATES OF AMERICA" & year > 1933

replace rtaa = 1 if country_1 == "BELGIUM AND LUXEMBURG" & country_2 == "UNITED STATES OF AMERICA" & year > 1934

replace rtaa = 1 if country_2 == "BELGIUM AND LUXEMBURG" & country_1 == "UNITED STATES OF AMERICA" & year > 1934

replace rtaa = 1 if country_1 == "HAITI" & country_2 == "UNITED STATES OF AMERICA" & year > 1934

replace rtaa = 1 if country_2 == "HAITI" & country_1 == "UNITED STATES OF AMERICA" & year > 1934

replace rtaa = 1 if country_1 == "SWEDEN" & country_2 == "UNITED STATES OF AMERICA" & year > 1934

replace rtaa = 1 if country_2 == "SWEDEN" & country_1 == "UNITED STATES OF AMERICA" & year > 1934

replace rtaa = 1 if country_1 == "BRAZIL" & country_2 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_2 == "BRAZIL" & country_1 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_1 == "CANADA" & country_2 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_2 == "CANADA" & country_1 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_1 == "COLOMBIA" & country_2 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_2 == "COLOMBIA" & country_1 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_1 == "FINLAND" & country_2 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_2 == "FINLAND" & country_1 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_1 == "FRANCE" & country_2== "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_2 == "FRANCE" & country_1 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_1 == "GUATAMALA" & country_2 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_2 == "GUATAMALA" & country_1 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_1 == "HONDURAS" & country_2 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_2 == "HONDURAS" & country_1 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_1 == "NETHERLANDS" & country_2 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_2 == "NETHERLANDS" & country_1 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_1 == "NICARAGUA" & country_2 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_2 == "NICARAGUA" & country_1 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_1 == "SWITZERLAND" & country_2 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_2 == "SWITZERLAND" & country_1 == "UNITED STATES OF AMERICA" & year > 1935

replace rtaa = 1 if country_1 == "COSTA RICA" & country_2 == "UNITED STATES OF AMERICA" & year > 1936

replace rtaa = 1 if country_2 == "COSTA RICA" & country_1 == "UNITED STATES OF AMERICA" & year > 1936

replace rtaa = 1 if country_1 == "EL SALVADOR" & country_2 == "UNITED STATES OF AMERICA" & year > 1936

replace rtaa = 1 if country_2 == "EL SALVADOR" & country_1 == "UNITED STATES OF AMERICA" & year > 1936

replace rtaa = 1 if country_1 == "CZECHOSLOVAKIA" & country_2 == "UNITED STATES OF AMERICA" & year > 1937

replace rtaa = 1 if country_2 == "CZECHOSLOVAKIA" & country_1 == "UNITED STATES OF AMERICA" & year > 1937

replace rtaa = 1 if country_1 == "ECUADOR" & country_2 == "UNITED STATES OF AMERICA" & year > 1937

replace rtaa = 1 if country_2 == "ECUADOR" & country_1 == "UNITED STATES OF AMERICA" & year > 1937





* code retaliation dummy =1 if country listed as one of the ones retaliating to S_H  by raising tariffs in 1930 - source Jones+ Mann (Canada, Mexico, France, Italy, Spain, Australia, NZL, Cuba, Switzerland, Argentina)

gen retaliator=0 

*Canada
replace retaliator=1 if code_2=="CAN" & code_1=="USA" & y_q>=-119

*France
replace retaliator=1 if code_2=="FRA" & code_1=="USA" & y_q>=-119

*Italy
replace retaliator=1 if code_2=="ITA" & code_1=="USA" & y_q>=-118

*Spain
replace retaliator=1 if code_2=="ESP" & code_1=="USA" & y_q>=-118

*Switzerland
replace retaliator=1 if code_2=="CHE" & code_1=="USA" & y_q>=-117

*Argentina
replace retaliator=1 if code_2=="ARG" & code_1=="USA" & y_q>=-118

*Mexico
replace retaliator=1 if code_2=="MEX" & code_1=="USA" & y_q>=-118

*Cuba
replace retaliator=1 if code_2=="CUB" & code_1=="USA" & y_q>=-120

*Australia & NZL   (BRITISH OCEANIA)
replace retaliator=1 if code_2=="BOC" & code_1=="USA" & y_q>=-118




* code protest dummy =1 if country listed as one of the ones protesting S_H - according to congressional records (Argentina (ARG); Austria (AUT); Belgium (BEL); Canada (CAN); 
*Czechoslovak Republic (CZE); Denmark (DNK); Dominican Republic (DOM); Egypt (EGY); Finland (FIN); France (FRA); Germany  (DEU); Great Britain (GBR):
*Australia (AUS), Bahamas (BHS), Bermuda (BMU), Dominica (?), India (IND), Scotland (?),
*West Indian Colonies (?); Greece (GRC); GUATAMALA (GTN); Hungary (HUN); Honduras (HND);
*Irish Free State (IRL); Italy (ITA); Japan (JPN); Latvia (LVA); Mexico (MEX); Newfoundland (NFD)
*The Netherlands (NED); Norway (NOR); Paraguay (PRY); Persia (PMA); Portugal (PRT);
*Rumania (ROU); Spain (ESP); Sweden (SWE); Switzerland (CHE); Turkey (TUR); Union of
*South Africa (ZAF); Uruguay (URY).


gen protestor=0 
*ARG
replace protestor=1 if code_2=="ARG" & code_1=="USA" & y_q>= -123

*AUT
replace protestor=1 if code_2=="AUT" & code_1=="USA" & y_q>= -123

*BEL & Luxemburg
replace protestor=1 if code_2=="BLX" & code_1=="USA" & y_q>= -123

*CAN - no formal protest
replace protestor=1 if code_2=="CAN" & code_1=="USA" & y_q>= -124

*CZE
replace protestor=1 if code_2=="CZE" & code_1=="USA" & y_q>= -122

*DNK
replace protestor=1 if code_2=="DNK" & code_1=="USA" & y_q>= -123

*DOM
replace protestor=1 if code_2=="DOM" & code_1=="USA" & y_q>= -123

*EGY
*replace protestor=1 if code_2=="EGY" & code_1=="USA" & y_q>= -120
*take out since not in congressional records

*FIN
replace protestor=1 if code_2=="FIN" & code_1=="USA" & y_q>= -122

*FRA
replace protestor=1 if code_2=="FRA" & code_1=="USA" & y_q>= -123

*DEU
replace protestor=1 if code_2=="DEU" & code_1=="USA" & y_q>= -122

*GBR
replace protestor=1 if code_2=="GBR" & code_1=="USA" & y_q>= -124

*AUStralia - now British Oceania
replace protestor=1 if code_2=="BOC" & code_1=="USA" & y_q>= -124

*BHS - Bahamas, now British West Indies - BWI
replace protestor=1 if code_2=="BWI" & code_1=="USA" & y_q>= -124

*BMU - Bermuda - see above, merged with British West Indies
*replace protestor=1 if code_2=="BMU" & code_1=="USA" & y_q>= -124

*IND
replace protestor=1 if code_2=="IND" & code_1=="USA" & y_q>= -124

*GRC
replace protestor=1 if code_2=="GRC" & code_1=="USA" & y_q>= -123

*GTM
replace protestor=1 if code_2=="GTM" & code_1=="USA" & y_q>= -124

*HUN not mentioned in the congressional records
*replace protestor=1 if code_2=="HUN" & code_1=="USA" & y_q>= -120

*HND
replace protestor=1 if code_2=="HND" & code_1=="USA" & y_q>= -124

*IRL
replace protestor=1 if code_2=="IRL" & code_1=="USA" & y_q>= -123

*ITA
replace protestor=1 if code_2=="ITA" & code_1=="USA" & y_q>= -123

*JPN
replace protestor=1 if code_2=="JPN" & code_1=="USA" & y_q>= -122

*LVA
replace protestor=1 if code_2=="LVA" & code_1=="USA" & y_q>= -122

*MEX
replace protestor=1 if code_2=="MEX" & code_1=="USA" & y_q>= -123

*NFD -  not explicilty mentioned in the congressional records
*replace protestor=1 if code_2=="NFD" & code_1=="USA" & y_q>= -120

*NED
replace protestor=1 if code_2=="NED" & code_1=="USA" & y_q>= -123

*NOR
replace protestor=1 if code_2=="NOR" & code_1=="USA" & y_q>= -123

*PRY - now URUGUAY AND PARAGUAY  - UPA
replace protestor=1 if code_2=="UPA" & code_1=="USA" & y_q>= -122

*PMA - IRAN IRAQ AND AFGHANISTAN - AFG
replace protestor=1 if code_2=="AFG" & code_1=="USA" & y_q>= -124

*PRT
replace protestor=1 if code_2=="PRT" & code_1=="USA" & y_q>= -122

*ROU
replace protestor=1 if code_2=="ROU" & code_1=="USA" & y_q>= -123

*ESP
replace protestor=1 if code_2=="ESP" & code_1=="USA" & y_q>= -123

*SWE
replace protestor=1 if code_2=="SWE" & code_1=="USA" & y_q>= -122

*CHE
replace protestor=1 if code_2=="CHE" & code_1=="USA" & y_q>= -123 

*TUR
replace protestor=1 if code_2=="TUR" & code_1=="USA" & y_q>= -123 

*ZAF - not mentioned in the congressional records
*replace protestor=1 if code_2=="ZAF" & code_1=="USA" & y_q>= -120 

*URY - see above, now merged with Paraguay
*replace protestor=1 if code_2=="UPA" & code_1=="USA" & y_q>= -123 



*** code threatener as protestors that do not follow through with retaliation 

generate threatener=0
replace threatener=1 if protestor==1



replace threatener = 0 if retaliator == 1



*** generate responder as joint set of threateners and retaliators


gen responder = threatener+retaliator


tab responder
tab code_2 if responder==1

tab country_2 if responder==1

gen nonresponder=0
replace nonresponder=1 if code_1=="USA" & responder==0 & y_q>=-118





gen logflow = ln(flow)


encode code_1, gen(num_1)

encode code_2, gen(num_2)

egen exp_time=group(num_1 y_q)
egen imp_time=group(num_2 y_q)
egen pair_id=group(code_1 code_2)





levelsof code_1, local(levels_1)

foreach x of local levels_1{

gen `x'_exptous = 0
replace `x'_exptous = 1 if code_1 == "`x'" & country_2 == "UNITED STATES OF AMERICA" & y_q >=-118
}

levelsof code_2, local(levels_2)

foreach x of local levels_2{

gen `x'_impfromus = 0
replace `x'_impfromus = 1 if code_2 == "`x'" & country_1 == "UNITED STATES OF AMERICA" & y_q >=-118
}

gen us_exp = 0

replace us_exp = 1 if country_2 == "UNITED STATES OF AMERICA" & y_q >=-118

gen us_imp = 0

replace us_imp = 1 if country_1 == "UNITED STATES OF AMERICA" & y_q >=-118



label variable sterling "Sterling area"

label variable imp_pref "Imperial preference"

label variable reichsmark "Reichsmark area"

label variable gold "Gold bloc"

label variable angloirishwar "Anglo-Irish economic war"

label variable retaliator "Retaliator"

label variable nonresponder "Non-responder"

label variable protestor "Protestor"

label variable threatener "Threatener"

label variable responder "Responders"

label variable crisis "Shared financial crises"

label variable italysanctions "Italian sanctions"

label variable germanpolishwar "German-Polish trade war"

label variable ukempire_2 "British Empire"

label variable frenchempire_2 "French Empire"

label variable dutchempire_2 "Dutch Empire"

label variable portempire_2 "Portuguese Empire"

label variable belgianempire_2 "Belgian Empire"

label variable italianempire_2 "Italian Empire"

label variable usempire_2 "US Empire"

label variable sov1938_2 "Sovereign"

label variable sterling_2 "Sterling area"

label variable imp_pref_2 "Imperial preference"

label variable reichsmark_2 "Reichsmark area"

label variable gold_2 "Gold bloc"

label variable rtaa "RTAA"

label variable xrate "Bilateral exchange rate"



save mergeddata_q, replace




*** Now run regressions - this is the baseline gravity regression

clear all

use mergeddata_q

xtset pair y_q


*** the following produces the results in Table 4 ***


#delimit ;
   reghdfe logflow sterling imp_pref angloirishwar reichsmark gold rtaa crisis germanpolishwar italysanctions retaliator threatener  if flow>1 , 
   absorb(exp_time imp_time pair_id ) vce(cluster pair_id);
#delimit cr

estimates store OLS

outreg2 using baseline,   excel replace

#delimit ;
   ppmlhdfe flow sterling imp_pref angloirishwar reichsmark gold rtaa crisis germanpolishwar italysanctions retaliator threatener, 
   absorb(exp_time imp_time pair_id ) vce(cluster pair_id);
#delimit cr

estimates store PPML

outreg2 using baseline,  addstat(Pseudo R-squared, `e(r2_p)')   excel append




#delimit ;
   reghdfe logflow sterling imp_pref angloirishwar reichsmark gold rtaa crisis germanpolishwar italysanctions responder  if flow>1 , 
   absorb(exp_time imp_time pair_id ) vce(cluster pair_id);
#delimit cr

outreg2 using baseline,   excel append

estimates store OLS

#delimit ;
   ppmlhdfe flow sterling imp_pref angloirishwar reichsmark gold rtaa crisis germanpolishwar italysanctions responder  , 
   absorb(exp_time imp_time pair_id ) vce(cluster pair_id);
#delimit cr

outreg2 using baseline, addstat(Pseudo R-squared, `e(r2_p)')   excel append

estimates store PPML



*** Results for Table 5 - Sovereigns ***

preserve 


drop if sov1938_1 == 0

drop if sov1938_2 == 0



#delimit ;
   reghdfe logflow sterling imp_pref angloirishwar reichsmark gold rtaa crisis germanpolishwar italysanctions responder  if flow>1 , 
   absorb(i.num_1#i.quarter i.num_2#i.quarter i.num_1#i.num_2) vce(cluster i.num_1#i.quarter i.num_2#i.quarter i.num_1#i.num_2);
#delimit cr

outreg2 using sovereign,   excel replace

#delimit ;
   ppmlhdfe flow sterling imp_pref angloirishwar reichsmark gold rtaa crisis germanpolishwar italysanctions responder  , 
   absorb(i.num_1#i.quarter i.num_2#i.quarter i.num_1#i.num_2) vce(cluster i.num_1#i.quarter i.num_2#i.quarter i.num_1#i.num_2);
#delimit cr

outreg2 using sovereign, addstat(Pseudo R-squared, `e(r2_p)')   excel append


#delimit ;
   reghdfe logflow sterling imp_pref angloirishwar reichsmark gold rtaa crisis germanpolishwar italysanctions retaliator threatener  if flow>1 , 
   absorb(i.num_1#i.quarter i.num_2#i.quarter i.num_1#i.num_2) vce(cluster i.num_1#i.quarter i.num_2#i.quarter i.num_1#i.num_2);
#delimit cr

outreg2 using sovereign,   excel append

#delimit ;
   ppmlhdfe flow sterling imp_pref angloirishwar reichsmark gold rtaa crisis germanpolishwar italysanctions retaliator threatener  , 
   absorb(i.num_1#i.quarter i.num_2#i.quarter i.num_1#i.num_2) vce(cluster i.num_1#i.quarter i.num_2#i.quarter i.num_1#i.num_2);
#delimit cr

outreg2 using sovereign, addstat(Pseudo R-squared, `e(r2_p)')   excel append



restore




****sequantially  drop country pairs from the regression to see if any  one country is driving the results *****
**** produces results from Appendix D *****


**** Identify the trade partners with the US: ****
 tab code_1 if code_2=="USA" & logflow>0 & logflow<.

 
 
 foreach var in  ARG  CAN CHE  CUB FRA  ITA ESP MEX BOC  {

#delimit ;
   reghdfe logflow sterling imp_pref angloirishwar reichsmark gold rtaa crisis germanpolishwar italysanctions retaliator threatener  if flow>1  & code_2!="`var'" &   code_1!="`var'", 
   absorb(exp_time imp_time pair_id ) vce(cluster pair_id);
#delimit cr

estimates store OLS

outreg2 using robust_both_check2`var',   excel replace

#delimit ;
   ppmlhdfe flow sterling imp_pref angloirishwar reichsmark gold rtaa crisis germanpolishwar italysanctions retaliator threatener if code_2!="`var'" &   code_1!="`var'", 
   absorb(exp_time imp_time pair_id ) vce(cluster pair_id);
#delimit cr

estimates store PPML

outreg2 using robust_both_check2`var',  addstat(Pseudo R-squared, `e(r2_p)')  excel append


}



**** group retaliators into the ones with imperial preferences, the ones on the gold bloc and the rest - Appendix E *****

preserve


drop retaliator

gen retaliator=0
gen retaliator_imp_pref=0 
gen retaliator_gold=0

*Canada
replace retaliator_imp_pref=1 if code_2=="CAN" & code_1=="USA" & y_q>=-119

*France
replace retaliator_gold=1 if code_2=="FRA" & code_1=="USA" & y_q>=-119

*Italy
replace retaliator_gold=1 if code_2=="ITA" & code_1=="USA" & y_q>=-118

*Spain
replace retaliator=1 if code_2=="ESP" & code_1=="USA" & y_q>=-118

*Switzerland
replace retaliator_gold=1 if code_2=="CHE" & code_1=="USA" & y_q>=-117

*Argentina
replace retaliator=1 if code_2=="ARG" & code_1=="USA" & y_q>=-118

*Mexico
replace retaliator=1 if code_2=="MEX" & code_1=="USA" & y_q>=-118

*Cuba
replace retaliator=1 if code_2=="CUB" & code_1=="USA" & y_q>=-120

*Australia & NZL   (BRITISH OCEANIA)
replace retaliator_imp_pref=1 if code_2=="BOC" & code_1=="USA" & y_q>=-118

tab code_2 if retaliator==1
tab code_2 if retaliator_imp_pref==1
tab code_2 if retaliator_gold==1

#delimit ;
   reghdfe logflow sterling angloirishwar reichsmark rtaa crisis germanpolishwar italysanctions retaliator retaliator_imp_pref retaliator_gold threatener  if flow>1 , 
   absorb(exp_time imp_time pair_id ) vce(cluster pair_id); 
#delimit cr

estimates store OLS

outreg2 using robust_interact,   excel replace

#delimit ;
   ppmlhdfe flow sterling angloirishwar reichsmark  rtaa crisis germanpolishwar italysanctions retaliator retaliator_imp_pref retaliator_gold threatener , 
   absorb(exp_time imp_time pair_id ) vce(cluster pair_id);
#delimit cr

estimates store PPML

outreg2 using robust_interact,  addstat(Pseudo R-squared, `e(r2_p)')  excel append


restore




**** creating summary tables ****

clear all

use mergeddata_q


*** generate summary stats for Table 1
preserve

keep if year==1928
keep if code_1=="USA"
  
 collapse (sum)  flow (firstnm) country_2, by (code_2)

gen exports=-flow

sort exports code_2 country_2, stable

replace exports=-exports

 export excel using "TopUSexports.xlsx", replace

restore




preserve

keep if year==1928
keep if code_2=="USA"
  
 collapse (sum)  flow (firstnm) country_1, by (code_1)
  
  gen imports=-flow

sort imports code_1 country_1, stable

replace imports=-imports


 export excel using "TopUSimports.xlsx", replace

restore



*****  generate table of all the trade declines  (1932Q4-1929Q4) ***** (Table 2, second column)


tsset pair y_q

gen trade_drop = flow if code_2=="USA"
by pair: gen d_trade_drop = trade_drop[_n-12]

replace trade_drop = (trade_drop - d_trade_drop )*100/d_trade_drop



* retaliators:

log using TradeDrop.log, replace
tab  trade_drop  if y_q==-109 & code_1=="ARG"
tab  trade_drop  if y_q==-109 & code_1=="BOC"
tab  trade_drop  if y_q==-109 & code_1=="CAN"
tab  trade_drop  if y_q==-109 & code_1=="CHE"
tab  trade_drop  if y_q==-109 & code_1=="CUB"
tab  trade_drop  if y_q==-109 & code_1=="ESP"
tab  trade_drop  if y_q==-109 & code_1=="FRA"
tab  trade_drop  if y_q==-109 & code_1=="ITA"
tab  trade_drop  if y_q==-109 & code_1=="MEX"



* threateners:

  
		
tab  trade_drop  if y_q==-109 & code_1=="AFG"
tab  trade_drop  if y_q==-109 & code_1=="AUT"
tab  trade_drop  if y_q==-109 & code_1=="BLX"
tab  trade_drop  if y_q==-109 & code_1=="BWI"
tab  trade_drop  if y_q==-109 & code_1=="CZE"
tab  trade_drop  if y_q==-109 & code_1=="DEU"
tab  trade_drop  if y_q==-109 & code_1=="DNK"
tab  trade_drop  if y_q==-109 & code_1=="DOM"
tab  trade_drop  if y_q==-109 & code_1=="EGY"
tab  trade_drop  if y_q==-109 & code_1=="FIN"
tab  trade_drop  if y_q==-109 & code_1=="GBR"
tab  trade_drop  if y_q==-109 & code_1=="GRC"
tab  trade_drop  if y_q==-109 & code_1=="GTM"
tab  trade_drop  if y_q==-109 & code_1=="HND"
tab  trade_drop  if y_q==-109 & code_1=="IRL"
tab  trade_drop  if y_q==-109 & code_1=="IND"
tab  trade_drop  if y_q==-109 & code_1=="JPN"
tab  trade_drop  if y_q==-109 & code_1=="LVA"
tab  trade_drop  if y_q==-109 & code_1=="NED"
tab  trade_drop  if y_q==-109 & code_1=="NOR"
tab  trade_drop  if y_q==-109 & code_1=="PRT"
tab  trade_drop  if y_q==-109 & code_1=="ROU"
tab  trade_drop  if y_q==-109 & code_1=="SWE"
tab  trade_drop  if y_q==-109 & code_1=="TUR"
tab  trade_drop  if y_q==-109 & code_1=="UPA"
		
		
		log close
